/* linux/include/asm-arm/plat-s5p/regs-gpio.h
 *
 * Copyright (c) 2008 Samsung Electronics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * S5PC1XX GPIO register definitions
 */

#ifndef _ASM_PLAT_REGS_GPIO_H_
#define _ASM_PLAT_REGS_GPIO_H_

/* utility macros */
#define S5P_GPIO_REG(x)			(S3C24XX_VA_GPIO + (x))
#define S5P_GPIO_NO(bank, offset)	((bank) + (offset))
#define S5P_GPIO_BASE(pin)		((pin & ~0x1F) >> 5)
#define	S5P_GPIO_OFFSET(pin)		(pin & 0x1F)

/* input/output */
#define S5P_GPIO_INPUT			(0x0)
#define S5P_GPIO_OUTPUT			(0x1)

/* pull up/down bit values */
#define S5P_GPIO_PUD_DISABLE		(0x0)
#define S5P_GPIO_PD_ENABLE		(0x1)
#define S5P_GPIO_PU_ENABLE		(0x2)

/* drive strength bit values */
#define S5P_GPIO_DRV_1X			(0x0)
#define S5P_GPIO_DRV_2X			(0x1)
#define S5P_GPIO_DRV_3X			(0x2)
#define S5P_GPIO_DRV_4X			(0x3)

/* power down control */
#define S5P_GPIO_PDNCON_OUTPUT0		(0x0)
#define S5P_GPIO_PDNCON_OUTPUT1		(0x1)
#define S5P_GPIO_PDNCON_INPUT		(0x2)
#define S5P_GPIO_PDNCON_PREV_STATE	(0x3)

/* external interrupt trigger bit values */
#define S5P_GPIO_EINT_LOW		(0x0)
#define S5P_GPIO_EINT_HIGH		(0x1)
#define S5P_GPIO_EINT_FALLING		(0x2)
#define S5P_GPIO_EINT_RISING		(0x3)
#define S5P_GPIO_EINT_BOTH		(0x4)

/* bank list */
#define S5P_GPIO_BANK_A0		(32 * 0)
#define S5P_GPIO_BANK_A1		(32 * 1)
#define S5P_GPIO_BANK_B			(32 * 2)
#define S5P_GPIO_BANK_C			(32 * 3)
#define S5P_GPIO_BANK_D			(32 * 4)
#define S5P_GPIO_BANK_E0		(32 * 5)
#define S5P_GPIO_BANK_E1		(32 * 6)
#define S5P_GPIO_BANK_F0		(32 * 7)
#define S5P_GPIO_BANK_F1		(32 * 8)
#define S5P_GPIO_BANK_F2		(32 * 9)
#define S5P_GPIO_BANK_F3		(32 * 10)
#define S5P_GPIO_BANK_G0		(32 * 11)
#define S5P_GPIO_BANK_G1		(32 * 12)
#define S5P_GPIO_BANK_G2		(32 * 13)
#define S5P_GPIO_BANK_G3		(32 * 14)
#define S5P_GPIO_BANK_H0		(32 * 15)
#define S5P_GPIO_BANK_H1		(32 * 16)
#define S5P_GPIO_BANK_H2		(32 * 17)
#define S5P_GPIO_BANK_H3		(32 * 18)
#define S5P_GPIO_BANK_I			(32 * 19)
#define S5P_GPIO_BANK_J0		(32 * 20)
#define S5P_GPIO_BANK_J1		(32 * 21)
#define S5P_GPIO_BANK_J2		(32 * 22)
#define S5P_GPIO_BANK_J3		(32 * 23)
#define S5P_GPIO_BANK_J4		(32 * 24)
#define S5P_GPIO_BANK_K0		(32 * 25)
#define S5P_GPIO_BANK_K1		(32 * 26)
#define S5P_GPIO_BANK_K2		(32 * 27)
#define S5P_GPIO_BANK_K3		(32 * 28)
#define S5P_GPIO_BANK_MP0_0		(32 * 29)
#define S5P_GPIO_BANK_MP0_1		(32 * 30)
#define S5P_GPIO_BANK_MP0_2		(32 * 31)
#define S5P_GPIO_BANK_MP0_3		(32 * 32)
#define S5P_GPIO_BANK_MP0_4		(32 * 33)
#define S5P_GPIO_BANK_MP1_0		(32 * 34)
#define S5P_GPIO_BANK_MP1_1		(32 * 35)
#define S5P_GPIO_BANK_MP1_2		(32 * 36)
#define S5P_GPIO_BANK_MP1_3		(32 * 37)
#define S5P_GPIO_BANK_MP1_4		(32 * 38)
#define S5P_GPIO_BANK_MP1_5		(32 * 39)
#define S5P_GPIO_BANK_MP1_6		(32 * 40)
#define S5P_GPIO_BANK_MP1_7		(32 * 41)
#define S5P_GPIO_BANK_MP1_8		(32 * 42)
#define S5P_GPIO_BANK_ETC0		(32 * 43)
#define S5P_GPIO_BANK_ETC1		(32 * 44)
#define S5P_GPIO_BANK_ETC2		(32 * 45)
#define S5P_GPIO_BANK_ETC3		(32 * 46)
#define S5P_GPIO_BANK_ETC4		(32 * 47)

/* GPA0 */
#define S5P_GPA0_CON			S5P_GPIO_REG(0x00)
#define S5P_GPA0_DAT			S5P_GPIO_REG(0x04)
#define S5P_GPA0_PUD			S5P_GPIO_REG(0x08)
#define S5P_GPA0_DRV			S5P_GPIO_REG(0x0C)
#define S5P_GPA0_CONPDN			S5P_GPIO_REG(0x10)
#define S5P_GPA0_PUDPDN			S5P_GPIO_REG(0x14)

#define S5P_GPA0_0			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 0)
#define S5P_GPA0_0_IN			(0x0)
#define S5P_GPA0_0_OUT			(0x1)
#define S5P_GPA0_0_UART0_RXD		(0x2)
#define S5P_GPA0_0_EXT_INT1_0		(0xF)

#define S5P_GPA0_1			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 1)
#define S5P_GPA0_1_IN			(0x0)
#define S5P_GPA0_1_OUT			(0x1)
#define S5P_GPA0_1_UART0_TXD		(0x2)
#define S5P_GPA0_1_EXT_INT1_1		(0xF)

#define S5P_GPA0_2			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 2)
#define S5P_GPA0_2_IN			(0x0)
#define S5P_GPA0_2_OUT			(0x1)
#define S5P_GPA0_2_UART0_CTSn		(0x2)
#define S5P_GPA0_2_EXT_INT1_2		(0xF)

#define S5P_GPA0_3			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 3)
#define S5P_GPA0_3_IN			(0x0)
#define S5P_GPA0_3_OUT			(0x1)
#define S5P_GPA0_3_UART0_RTSn		(0x2)
#define S5P_GPA0_3_EXT_INT1_3		(0xF)

#define S5P_GPA0_4			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 4)
#define S5P_GPA0_4_IN			(0x0)
#define S5P_GPA0_4_OUT			(0x1)
#define S5P_GPA0_4_UART1_RXD		(0x2)
#define S5P_GPA0_4_EXT_INT1_4		(0xF)

#define S5P_GPA0_5			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 5)
#define S5P_GPA0_5_IN			(0x0)
#define S5P_GPA0_5_OUT			(0x1)
#define S5P_GPA0_5_UART1_TXD		(0x2)
#define S5P_GPA0_5_EXT_INT1_5		(0xF)

#define S5P_GPA0_6			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 6)
#define S5P_GPA0_6_IN			(0x0)
#define S5P_GPA0_6_OUT			(0x1)
#define S5P_GPA0_6_UART1_CTSn		(0x2)
#define S5P_GPA0_6_EXT_INT1_6		(0xF)

#define S5P_GPA0_7			S5P_GPIO_NO(S5P_GPIO_BANK_A0, 7)
#define S5P_GPA0_7_IN			(0x0)
#define S5P_GPA0_7_OUT			(0x1)
#define S5P_GPA0_7_UART1_RTSn		(0x2)
#define S5P_GPA0_7_EXT_INT1_7		(0xF)

/* GPA1 */
#define S5P_GPA1_CON			S5P_GPIO_REG(0x20)
#define S5P_GPA1_DAT			S5P_GPIO_REG(0x24)
#define S5P_GPA1_PUD			S5P_GPIO_REG(0x28)
#define S5P_GPA1_DRV			S5P_GPIO_REG(0x2C)
#define S5P_GPA1_CONPDN			S5P_GPIO_REG(0x30)
#define S5P_GPA1_PUDPDN			S5P_GPIO_REG(0x34)

#define S5P_GPA1_0			S5P_GPIO_NO(S5P_GPIO_BANK_A1, 0)
#define S5P_GPA1_0_IN			(0x0)
#define S5P_GPA1_0_OUT			(0x1)
#define S5P_GPA1_0_UART2_RXD		(0x2)
#define S5P_GPA1_0_EXT_INT2_0		(0xF)

#define S5P_GPA1_1			S5P_GPIO_NO(S5P_GPIO_BANK_A1, 1)
#define S5P_GPA1_1_IN			(0x0)
#define S5P_GPA1_1_OUT			(0x1)
#define S5P_GPA1_1_UART2_TXD		(0x2)
#define S5P_GPA1_1_EXT_INT2_1		(0xF)

#define S5P_GPA1_2			S5P_GPIO_NO(S5P_GPIO_BANK_A1, 2)
#define S5P_GPA1_2_IN			(0x0)
#define S5P_GPA1_2_OUT			(0x1)
#define S5P_GPA1_2_UART3_RXD		(0x2)
#define S5P_GPA1_2_UART2_CTSn		(0x3)
#define S5P_GPA1_2_IRDA_RX_DATA		(0x4)
#define S5P_GPA1_2_EXT_INT2_2		(0xF)

#define S5P_GPA1_3			S5P_GPIO_NO(S5P_GPIO_BANK_A1, 3)
#define S5P_GPA1_3_IN			(0x0)
#define S5P_GPA1_3_OUT			(0x1)
#define S5P_GPA1_3_UART3_TXD		(0x2)
#define S5P_GPA1_3_UART2_RTSn		(0x3)
#define S5P_GPA1_3_IRDA_TX_DATA		(0x4)
#define S5P_GPA1_3_EXT_INT2_3		(0xF)

#define S5P_GPA1_4			S5P_GPIO_NO(S5P_GPIO_BANK_A1, 4)
#define S5P_GPA1_4_IN			(0x0)
#define S5P_GPA1_4_OUT			(0x1)
#define S5P_GPA1_4_UARTCLK		(0x2)
#define S5P_GPA1_4_IRDA_SDBW		(0x4)
#define S5P_GPA1_4_EXT_INT2_4		(0xF)

/* GPB */
#define S5P_GPB0_CON			S5P_GPIO_REG(0x40)
#define S5P_GPB0_DAT			S5P_GPIO_REG(0x44)
#define S5P_GPB0_PUD			S5P_GPIO_REG(0x48)
#define S5P_GPB0_DRV			S5P_GPIO_REG(0x4C)
#define S5P_GPB0_CONPDN			S5P_GPIO_REG(0x50)
#define S5P_GPB0_PUDPDN			S5P_GPIO_REG(0x54)

#define S5P_GPB0			S5P_GPIO_NO(S5P_GPIO_BANK_B, 0)
#define S5P_GPB0_IN			(0x0)
#define S5P_GPB0_OUT			(0x1)
#define S5P_GPB0_SPI0_MISO		(0x2)
#define S5P_GPB0_EXT_INT3_0		(0xF)

#define S5P_GPB1			S5P_GPIO_NO(S5P_GPIO_BANK_B, 1)
#define S5P_GPB1_IN			(0x0)
#define S5P_GPB1_OUT			(0x1)
#define S5P_GPB1_SPI0_CLK		(0x2)
#define S5P_GPB1_EXT_INT3_1		(0xF)

#define S5P_GPB2			S5P_GPIO_NO(S5P_GPIO_BANK_B, 2)
#define S5P_GPB2_IN			(0x0)
#define S5P_GPB2_OUT			(0x1)
#define S5P_GPB2_SPI0_MOSI		(0x2)
#define S5P_GPB2_EXT_INT3_2		(0xF)

#define S5P_GPB3			S5P_GPIO_NO(S5P_GPIO_BANK_B, 3)
#define S5P_GPB3_IN			(0x0)
#define S5P_GPB3_OUT			(0x1)
#define S5P_GPB3_SPI0_nSS		(0x2)
#define S5P_GPB3_EXT_INT3_3		(0xF)

#define S5P_GPB4			S5P_GPIO_NO(S5P_GPIO_BANK_B, 4)
#define S5P_GPB4_IN			(0x0)
#define S5P_GPB4_OUT			(0x1)
#define S5P_GPB4_SPI1_MISO		(0x2)
#define S5P_GPB4_EXT_INT3_4		(0xF)

#define S5P_GPB5			S5P_GPIO_NO(S5P_GPIO_BANK_B, 5)
#define S5P_GPB5_IN			(0x0)
#define S5P_GPB5_OUT			(0x1)
#define S5P_GPB5_SPI1_CLK		(0x2)
#define S5P_GPB5_EXT_INT3_5		(0xF)

#define S5P_GPB6			S5P_GPIO_NO(S5P_GPIO_BANK_B, 6)
#define S5P_GPB6_IN			(0x0)
#define S5P_GPB6_OUT			(0x1)
#define S5P_GPB6_SPI1_MOSI		(0x2)
#define S5P_GPB6_EXT_INT3_6		(0xF)

#define S5P_GPB7			S5P_GPIO_NO(S5P_GPIO_BANK_B, 7)
#define S5P_GPB7_IN			(0x0)
#define S5P_GPB7_OUT			(0x1)
#define S5P_GPB7_SPI1_nSS		(0x2)
#define S5P_GPB7_EXT_INT3_7		(0xF)

/* GPC */
#define S5P_GPC0_CON			S5P_GPIO_REG(0x60)
#define S5P_GPC0_DAT			S5P_GPIO_REG(0x64)
#define S5P_GPC0_PUD			S5P_GPIO_REG(0x68)
#define S5P_GPC0_DRV			S5P_GPIO_REG(0x6C)
#define S5P_GPC0_CONPDN			S5P_GPIO_REG(0x70)
#define S5P_GPC0_PUDPDN			S5P_GPIO_REG(0x74)

#define S5P_GPC0			S5P_GPIO_NO(S5P_GPIO_BANK_C, 0)
#define S5P_GPC0_IN			(0x0)
#define S5P_GPC0_OUT			(0x1)
#define S5P_GPC0_I2S1_SCLK		(0x2)
#define S5P_GPC0_PCM1_SCLK		(0x3)
#define S5P_GPC0_AC97_BITCLK		(0x4)
#define S5P_GPC0_EXT_INT4_0		(0xF)

#define S5P_GPC1			S5P_GPIO_NO(S5P_GPIO_BANK_C, 1)
#define S5P_GPC1_IN			(0x0)
#define S5P_GPC1_OUT			(0x1)
#define S5P_GPC1_I2S1_CDCLK		(0x2)
#define S5P_GPC1_PCM1_EXTCLK		(0x3)
#define S5P_GPC1_AC97_RESETn		(0x4)
#define S5P_GPC1_EXT_INT4_1		(0xF)

#define S5P_GPC2			S5P_GPIO_NO(S5P_GPIO_BANK_C, 2)
#define S5P_GPC2_IN			(0x0)
#define S5P_GPC2_OUT			(0x1)
#define S5P_GPC2_I2S1_LRCK		(0x2)
#define S5P_GPC2_PCM1_FSYNC		(0x3)
#define S5P_GPC2_AC97_SYNC		(0x4)
#define S5P_GPC2_EXT_INT4_2		(0xF)

#define S5P_GPC3			S5P_GPIO_NO(S5P_GPIO_BANK_C, 3)
#define S5P_GPC3_IN			(0x0)
#define S5P_GPC3_OUT			(0x1)
#define S5P_GPC3_I2S1_SDI		(0x2)
#define S5P_GPC3_PCM1_SIN		(0x3)
#define S5P_GPC3_AC97_SDI		(0x4)
#define S5P_GPC3_EXT_INT4_3		(0xF)

#define S5P_GPC4			S5P_GPIO_NO(S5P_GPIO_BANK_C, 4)
#define S5P_GPC4_IN			(0x0)
#define S5P_GPC4_OUT			(0x1)
#define S5P_GPC4_I2S1_SDO		(0x2)
#define S5P_GPC4_PCM1_SOUT		(0x3)
#define S5P_GPC4_AC97_SDO		(0x4)
#define S5P_GPC4_EXT_INT4_4		(0xF)

/* GPD */
#define S5P_GPD0_CON			S5P_GPIO_REG(0x80)
#define S5P_GPD0_DAT			S5P_GPIO_REG(0x84)
#define S5P_GPD0_PUD			S5P_GPIO_REG(0x88)
#define S5P_GPD0_DRV			S5P_GPIO_REG(0x8C)
#define S5P_GPD0_CONPDN			S5P_GPIO_REG(0x90)
#define S5P_GPD0_PUDPDN			S5P_GPIO_REG(0x94)

#define S5P_GPD0			S5P_GPIO_NO(S5P_GPIO_BANK_D, 0)
#define S5P_GPD0_IN			(0x0)
#define S5P_GPD0_OUT			(0x1)
#define S5P_GPD0_TOUT0			(0x2)
#define S5P_GPD0_PWM_TCLK 		(0x3)
#define S5P_GPD0_EXT_INT5_0		(0xF)

#define S5P_GPD1			S5P_GPIO_NO(S5P_GPIO_BANK_D, 1)
#define S5P_GPD1_IN			(0x0)
#define S5P_GPD1_OUT			(0x1)
#define S5P_GPD1_TOUT1			(0x2)
#define S5P_GPD1_EX_DMA_REQn		(0x3)
#define S5P_GPD1_EXT_INT5_1		(0xF)

#define S5P_GPD2			S5P_GPIO_NO(S5P_GPIO_BANK_D, 2)
#define S5P_GPD2_IN			(0x0)
#define S5P_GPD2_OUT			(0x1)
#define S5P_GPD2_TOUT2			(0x2)
#define S5P_GPD2_EX_DMA_ACKn		(0x3)
#define S5P_GPD2_EXT_INT5_2		(0xF)

#define S5P_GPD3			S5P_GPIO_NO(S5P_GPIO_BANK_D, 3)
#define S5P_GPD3_IN			(0x0)
#define S5P_GPD3_OUT			(0x1)
#define S5P_GPD3_I2C0_SDA		(0x2)
#define S5P_GPD3_EXT_INT5_3		(0xF)

#define S5P_GPD4			S5P_GPIO_NO(S5P_GPIO_BANK_D, 4)
#define S5P_GPD4_IN			(0x0)
#define S5P_GPD4_OUT			(0x1)
#define S5P_GPD4_I2C0_SCL		(0x2)
#define S5P_GPD4_EXT_INT5_4		(0xF)

#define S5P_GPD5			S5P_GPIO_NO(S5P_GPIO_BANK_D, 5)
#define S5P_GPD5_IN			(0x0)
#define S5P_GPD5_OUT			(0x1)
#define S5P_GPD5_I2C1_SDA		(0x2)
#define S5P_GPD5_SPDIF0_OUT		(0x3)
#define S5P_GPD5_EXT_INT5_5		(0xF)

#define S5P_GPD6			S5P_GPIO_NO(S5P_GPIO_BANK_D, 6)
#define S5P_GPD6_IN			(0x0)
#define S5P_GPD6_OUT			(0x1)
#define S5P_GPD6_I2C1_SCL		(0x2)
#define S5P_GPD5_SPDIF_EXTCLK		(0x3)
#define S5P_GPD6_EXT_INT5_6		(0xF)

/* GPE0 */
#define S5P_GPE0_CON			S5P_GPIO_REG(0xA0)
#define S5P_GPE0_DAT			S5P_GPIO_REG(0xA4)
#define S5P_GPE0_PUD			S5P_GPIO_REG(0xA8)
#define S5P_GPE0_DRV			S5P_GPIO_REG(0xAC)
#define S5P_GPE0_CONPDN			S5P_GPIO_REG(0xB0)
#define S5P_GPE0_PUDPDN			S5P_GPIO_REG(0xB4)

#define S5P_GPE0_0			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 0)
#define S5P_GPE0_0_IN			(0x0)
#define S5P_GPE0_0_OUT			(0x1)
#define S5P_GPE0_0_CAM_A_PCLK		(0x2)
#define S5P_GPE0_0_SD1_CLK		(0x3)
#define S5P_GPE0_0_EXT_INT6_0		(0xF)

#define S5P_GPE0_1			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 1)
#define S5P_GPE0_1_IN			(0x0)
#define S5P_GPE0_1_OUT			(0x1)
#define S5P_GPE0_1_CAM_A_VSYNC		(0x2)
#define S5P_GPE0_1_SD1_CDn		(0x3)
#define S5P_GPE0_1_EXT_INT6_1		(0xF)

#define S5P_GPE0_2			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 2)
#define S5P_GPE0_2_IN			(0x0)
#define S5P_GPE0_2_OUT			(0x1)
#define S5P_GPE0_2_CAM_A_HREF		(0x2)
#define S5P_GPE0_2_SD1_CMD		(0x3)
#define S5P_GPE0_2_EXT_INT6_2		(0xF)

#define S5P_GPE0_3			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 3)
#define S5P_GPE0_3_IN			(0x0)
#define S5P_GPE0_3_OUT			(0x1)
#define S5P_GPE0_3_CAM_A_DATA0		(0x2)
#define S5P_GPE0_3_SD1_DATA0		(0x3)
#define S5P_GPE0_3_EXT_INT6_3		(0xF)

#define S5P_GPE0_4			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 4)
#define S5P_GPE0_4_IN			(0x0)
#define S5P_GPE0_4_OUT			(0x1)
#define S5P_GPE0_4_CAM_A_DATA1		(0x2)
#define S5P_GPE0_4_SD1_DATA1		(0x3)
#define S5P_GPE0_4_EXT_INT6_4		(0xF)

#define S5P_GPE0_5			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 5)
#define S5P_GPE0_5_IN			(0x0)
#define S5P_GPE0_5_OUT			(0x1)
#define S5P_GPE0_5_CAM_A_DATA2		(0x2)
#define S5P_GPE0_5_SD1_DATA2		(0x3)
#define S5P_GPE0_5_EXT_INT6_5		(0xF)

#define S5P_GPE0_6			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 6)
#define S5P_GPE0_6_IN			(0x0)
#define S5P_GPE0_6_OUT			(0x1)
#define S5P_GPE0_6_CAM_A_DATA3		(0x2)
#define S5P_GPE0_6_SD1_DATA3		(0x3)
#define S5P_GPE0_6_EXT_INT6_6		(0xF)

#define S5P_GPE0_7			S5P_GPIO_NO(S5P_GPIO_BANK_E0, 7)
#define S5P_GPE0_7_IN			(0x0)
#define S5P_GPE0_7_OUT			(0x1)
#define S5P_GPE0_7_CAM_A_DATA4		(0x2)
#define S5P_GPE0_7_SD1_DATA4		(0x3)
#define S5P_GPE0_7_EXT_INT6_7		(0xF)

/* GPE1 */
#define S5P_GPE1_CON			S5P_GPIO_REG(0xC0)
#define S5P_GPE1_DAT			S5P_GPIO_REG(0xC4)
#define S5P_GPE1_PUD			S5P_GPIO_REG(0xC8)
#define S5P_GPE1_DRV			S5P_GPIO_REG(0xDC)
#define S5P_GPE1_CONPDN			S5P_GPIO_REG(0xD0)
#define S5P_GPE1_PUDPDN			S5P_GPIO_REG(0xD4)

#define S5P_GPE1_0			S5P_GPIO_NO(S5P_GPIO_BANK_E1, 0)
#define S5P_GPE1_0_IN			(0x0)
#define S5P_GPE1_0_OUT			(0x1)
#define S5P_GPE1_0_CAM_A_DATA5		(0x2)
#define S5P_GPE1_0_SD1_DATA5		(0x3)
#define S5P_GPE1_0_EXT_INT7_0		(0xF)

#define S5P_GPE1_1			S5P_GPIO_NO(S5P_GPIO_BANK_E1, 1)
#define S5P_GPE1_1_IN			(0x0)
#define S5P_GPE1_1_OUT			(0x1)
#define S5P_GPE1_1_CAM_A_DATA6		(0x2)
#define S5P_GPE1_1_SD1_DATA6		(0x3)
#define S5P_GPE1_1_EXT_INT7_1		(0xF)

#define S5P_GPE1_2			S5P_GPIO_NO(S5P_GPIO_BANK_E1, 2)
#define S5P_GPE1_2_IN			(0x0)
#define S5P_GPE1_2_OUT			(0x1)
#define S5P_GPE1_2_CAM_A_DATA7		(0x2)
#define S5P_GPE1_2_SD1_DATA7		(0x3)
#define S5P_GPE1_2_EXT_INT7_2		(0xF)

#define S5P_GPE1_3			S5P_GPIO_NO(S5P_GPIO_BANK_E1, 3)
#define S5P_GPE1_3_IN			(0x0)
#define S5P_GPE1_3_OUT			(0x1)
#define S5P_GPE1_3_CAM_A_CLKOUT		(0x2)
#define S5P_GPE1_3_EXT_INT7_3		(0xF)

#define S5P_GPE1_4			S5P_GPIO_NO(S5P_GPIO_BANK_E1, 4)
#define S5P_GPE1_4_IN			(0x0)
#define S5P_GPE1_4_OUT			(0x1)
#define S5P_GPE1_4_CAM_A_RESET		(0x2)
#define S5P_GPE1_4_EXT_INT7_4		(0xF)

#define S5P_GPE1_5			S5P_GPIO_NO(S5P_GPIO_BANK_E1, 5)
#define S5P_GPE1_5_IN			(0x0)
#define S5P_GPE1_5_OUT			(0x1)
#define S5P_GPE1_5_CAM_A_FLASH		(0x2)
#define S5P_GPE1_5_EXT_INT7_4		(0xF)

/* GPF0 */
#define S5P_GPF0_CON			S5P_GPIO_REG(0xE0)
#define S5P_GPF0_DAT			S5P_GPIO_REG(0xE4)
#define S5P_GPF0_PUD			S5P_GPIO_REG(0xE8)
#define S5P_GPF0_DRV			S5P_GPIO_REG(0xEC)
#define S5P_GPF0_CONPDN			S5P_GPIO_REG(0xF0)
#define S5P_GPF0_PUDPDN			S5P_GPIO_REG(0xF4)

#define S5P_GPF0_0			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 0)
#define S5P_GPF0_0_IN			(0x0)
#define S5P_GPF0_0_OUT			(0x1)
#define S5P_GPF0_0_LCD_HSYNC		(0x2)
#define S5P_GPF0_0_SYS_CS0		(0x3)
#define S5P_GPF0_0_VEN_HSYNC		(0x4)
#define S5P_GPF0_0_EXT_INT8_0		(0xF)

#define S5P_GPF0_1			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 1)
#define S5P_GPF0_1_IN			(0x0)
#define S5P_GPF0_1_OUT			(0x1)
#define S5P_GPF0_1_LCD_VSYNC		(0x2)
#define S5P_GPF0_1_SYS_CS1		(0x3)
#define S5P_GPF0_1_VEN_VSYNC		(0x4)
#define S5P_GPF0_1_EXT_INT8_1		(0xF)

#define S5P_GPF0_2			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 2)
#define S5P_GPF0_2_IN			(0x0)
#define S5P_GPF0_2_OUT			(0x1)
#define S5P_GPF0_2_LCD_VDEN		(0x2)
#define S5P_GPF0_2_SYS_RS		(0x3)
#define S5P_GPF0_2_VEN_HREF		(0x4)
#define S5P_GPF0_2_EXT_INT8_2		(0xF)

#define S5P_GPF0_3			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 3)
#define S5P_GPF0_3_IN			(0x0)
#define S5P_GPF0_3_OUT			(0x1)
#define S5P_GPF0_3_LCD_VCLK		(0x2)
#define S5P_GPF0_3_SYS_WE		(0x3)
#define S5P_GPF0_3_V601_CLK		(0x4)
#define S5P_GPF0_3_EXT_INT8_3		(0xF)

#define S5P_GPF0_4			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 4)
#define S5P_GPF0_4_IN			(0x0)
#define S5P_GPF0_4_OUT			(0x1)
#define S5P_GPF0_4_LCD_VD0		(0x2)
#define S5P_GPF0_4_SYS_VD0		(0x3)
#define S5P_GPF0_4_VEN_DATA0		(0x4)
#define S5P_GPF0_4_EXT_INT8_4		(0xF)

#define S5P_GPF0_5			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 5)
#define S5P_GPF0_5_IN			(0x0)
#define S5P_GPF0_5_OUT			(0x1)
#define S5P_GPF0_5_LCD_VD1		(0x2)
#define S5P_GPF0_5_SYS_VD1		(0x3)
#define S5P_GPF0_5_VEN_DATA1		(0x4)
#define S5P_GPF0_5_EXT_INT8_5		(0xF)

#define S5P_GPF0_6			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 6)
#define S5P_GPF0_6_IN			(0x0)
#define S5P_GPF0_6_OUT			(0x1)
#define S5P_GPF0_6_LCD_VD2		(0x2)
#define S5P_GPF0_6_SYS_VD2		(0x3)
#define S5P_GPF0_6_VEN_DATA2		(0x4)
#define S5P_GPF0_6_EXT_INT8_6		(0xF)

#define S5P_GPF0_7			S5P_GPIO_NO(S5P_GPIO_BANK_F0, 7)
#define S5P_GPF0_7_IN			(0x0)
#define S5P_GPF0_7_OUT			(0x1)
#define S5P_GPF0_7_LCD_VD3		(0x2)
#define S5P_GPF0_7_SYS_VD3		(0x3)
#define S5P_GPF0_7_VEN_DATA3		(0x4)
#define S5P_GPF0_7_EXT_INT8_7		(0xF)

/* GPF1 */
#define S5P_GPF1_CON			S5P_GPIO_REG(0x100)
#define S5P_GPF1_DAT			S5P_GPIO_REG(0x104)
#define S5P_GPF1_PUD			S5P_GPIO_REG(0x108)
#define S5P_GPF1_DRV			S5P_GPIO_REG(0x10C)
#define S5P_GPF1_CONPDN			S5P_GPIO_REG(0x110)
#define S5P_GPF1_PUDPDN			S5P_GPIO_REG(0x114)

#define S5P_GPF1_0			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 0)
#define S5P_GPF1_0_IN			(0x0)
#define S5P_GPF1_0_OUT			(0x1)
#define S5P_GPF1_0_LCD_VD4		(0x2)
#define S5P_GPF1_0_SYS_VD4		(0x3)
#define S5P_GPF1_0_VEN_DATA4		(0x4)
#define S5P_GPF1_0_EXT_INT9_0		(0xF)

#define S5P_GPF1_1			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 1)
#define S5P_GPF1_1_IN			(0x0)
#define S5P_GPF1_1_OUT			(0x1)
#define S5P_GPF1_1_LCD_VD5		(0x2)
#define S5P_GPF1_1_SYS_VD5		(0x3)
#define S5P_GPF1_1_VEN_DATA5		(0x4)
#define S5P_GPF1_1_EXT_INT9_1		(0xF)

#define S5P_GPF1_2			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 2)
#define S5P_GPF1_2_IN			(0x0)
#define S5P_GPF1_2_OUT			(0x1)
#define S5P_GPF1_2_LCD_VD6		(0x2)
#define S5P_GPF1_2_SYS_VD6		(0x3)
#define S5P_GPF1_2_VEN_DATA6		(0x4)
#define S5P_GPF1_2_EXT_INT9_2		(0xF)

#define S5P_GPF1_3			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 3)
#define S5P_GPF1_3_IN			(0x0)
#define S5P_GPF1_3_OUT			(0x1)
#define S5P_GPF1_3_LCD_VD7		(0x2)
#define S5P_GPF1_3_SYS_VD7		(0x3)
#define S5P_GPF1_3_VEN_DATA7		(0x4)
#define S5P_GPF1_3_EXT_INT9_3		(0xF)

#define S5P_GPF1_4			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 4)
#define S5P_GPF1_4_IN			(0x0)
#define S5P_GPF1_4_OUT			(0x1)
#define S5P_GPF1_4_LCD_VD8		(0x2)
#define S5P_GPF1_4_SYS_VD8		(0x3)
#define S5P_GPF1_4_V656_DATA0		(0x4)
#define S5P_GPF1_4_EXT_INT9_4		(0xF)

#define S5P_GPF1_5			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 5)
#define S5P_GPF1_5_IN			(0x0)
#define S5P_GPF1_5_OUT			(0x1)
#define S5P_GPF1_5_LCD_VD9		(0x2)
#define S5P_GPF1_5_SYS_VD9		(0x3)
#define S5P_GPF1_5_V656_DATA1		(0x4)
#define S5P_GPF1_5_EXT_INT9_5		(0xF)

#define S5P_GPF1_6			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 6)
#define S5P_GPF1_6_IN			(0x0)
#define S5P_GPF1_6_OUT			(0x1)
#define S5P_GPF1_6_LCD_VD10		(0x2)
#define S5P_GPF1_6_SYS_VD10		(0x3)
#define S5P_GPF1_6_V656_DATA2		(0x4)
#define S5P_GPF1_6_EXT_INT9_6		(0xF)

#define S5P_GPF1_7			S5P_GPIO_NO(S5P_GPIO_BANK_F1, 7)
#define S5P_GPF1_7_IN			(0x0)
#define S5P_GPF1_7_OUT			(0x1)
#define S5P_GPF1_7_LCD_VD11		(0x2)
#define S5P_GPF1_7_SYS_VD11		(0x3)
#define S5P_GPF1_7_V656_DATA3		(0x4)
#define S5P_GPF1_7_EXT_INT9_7		(0xF)

/* GPF2 */
#define S5P_GPF2_CON			S5P_GPIO_REG(0x120)
#define S5P_GPF2_DAT			S5P_GPIO_REG(0x124)
#define S5P_GPF2_PUD			S5P_GPIO_REG(0x128)
#define S5P_GPF2_DRV			S5P_GPIO_REG(0x12C)
#define S5P_GPF2_CONPDN			S5P_GPIO_REG(0x130)
#define S5P_GPF2_PUDPDN			S5P_GPIO_REG(0x134)

#define S5P_GPF2_0			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 0)
#define S5P_GPF2_0_IN			(0x0)
#define S5P_GPF2_0_OUT			(0x1)
#define S5P_GPF2_0_LCD_VD12		(0x2)
#define S5P_GPF2_0_SYS_VD12		(0x3)
#define S5P_GPF2_0_V656_DATA4		(0x4)
#define S5P_GPF2_0_EXT_INT10_0		(0xF)

#define S5P_GPF2_1			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 1)
#define S5P_GPF2_1_IN			(0x0)
#define S5P_GPF2_1_OUT			(0x1)
#define S5P_GPF2_1_LCD_VD13		(0x2)
#define S5P_GPF2_1_SYS_VD13		(0x3)
#define S5P_GPF2_1_V656_DATA5		(0x4)
#define S5P_GPF2_1_EXT_INT10_1		(0xF)

#define S5P_GPF2_2			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 2)
#define S5P_GPF2_2_IN			(0x0)
#define S5P_GPF2_2_OUT			(0x1)
#define S5P_GPF2_2_LCD_VD14		(0x2)
#define S5P_GPF2_2_SYS_VD14		(0x3)
#define S5P_GPF2_2_V656_DATA6		(0x4)
#define S5P_GPF2_2_EXT_INT10_2		(0xF)

#define S5P_GPF2_3			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 3)
#define S5P_GPF2_3_IN			(0x0)
#define S5P_GPF2_3_OUT			(0x1)
#define S5P_GPF2_3_LCD_VD15		(0x2)
#define S5P_GPF2_3_SYS_VD15		(0x3)
#define S5P_GPF2_3_V656_DATA7		(0x4)
#define S5P_GPF2_3_EXT_INT10_3		(0xF)

#define S5P_GPF2_4			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 4)
#define S5P_GPF2_4_IN			(0x0)
#define S5P_GPF2_4_OUT			(0x1)
#define S5P_GPF2_4_LCD_VD16		(0x2)
#define S5P_GPF2_4_SYS_VD16		(0x3)
#define S5P_GPF2_4_EXT_INT10_4		(0xF)

#define S5P_GPF2_5			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 5)
#define S5P_GPF2_5_IN			(0x0)
#define S5P_GPF2_5_OUT			(0x1)
#define S5P_GPF2_5_LCD_VD17		(0x2)
#define S5P_GPF2_5_SYS_VD17		(0x3)
#define S5P_GPF2_5_EXT_INT10_5		(0xF)

#define S5P_GPF2_6			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 6)
#define S5P_GPF2_6_IN			(0x0)
#define S5P_GPF2_6_OUT			(0x1)
#define S5P_GPF2_6_LCD_VD18		(0x2)
#define S5P_GPF2_6_EXT_INT10_6		(0xF)

#define S5P_GPF2_7			S5P_GPIO_NO(S5P_GPIO_BANK_F2, 7)
#define S5P_GPF2_7_IN			(0x0)
#define S5P_GPF2_7_OUT			(0x1)
#define S5P_GPF2_7_LCD_VD19		(0x2)
#define S5P_GPF2_7_EXT_INT10_7		(0xF)

/* GPF3 */
#define S5P_GPF3_CON			S5P_GPIO_REG(0x140)
#define S5P_GPF3_DAT			S5P_GPIO_REG(0x144)
#define S5P_GPF3_PUD			S5P_GPIO_REG(0x148)
#define S5P_GPF3_DRV			S5P_GPIO_REG(0x14C)
#define S5P_GPF3_CONPDN			S5P_GPIO_REG(0x150)
#define S5P_GPF3_PUDPDN			S5P_GPIO_REG(0x154)

#define S5P_GPF3_0			S5P_GPIO_NO(S5P_GPIO_BANK_F3, 0)
#define S5P_GPF3_0_IN			(0x0)
#define S5P_GPF3_0_OUT			(0x1)
#define S5P_GPF3_0_LCD_VD20		(0x2)
#define S5P_GPF3_0_EXT_INT11_0		(0xF)

#define S5P_GPF3_1			S5P_GPIO_NO(S5P_GPIO_BANK_F3, 1)
#define S5P_GPF3_1_IN			(0x0)
#define S5P_GPF3_1_OUT			(0x1)
#define S5P_GPF3_1_LCD_VD21		(0x2)
#define S5P_GPF3_1_EXT_INT11_1		(0xF)

#define S5P_GPF3_2			S5P_GPIO_NO(S5P_GPIO_BANK_F3, 2)
#define S5P_GPF3_2_IN			(0x0)
#define S5P_GPF3_2_OUT			(0x1)
#define S5P_GPF3_2_LCD_VD22		(0x2)
#define S5P_GPF3_2_VSYNC_LDI		(0x3)
#define S5P_GPF3_2_V656_CLK		(0x4)
#define S5P_GPF3_2_EXT_INT11_2		(0xF)

#define S5P_GPF3_3			S5P_GPIO_NO(S5P_GPIO_BANK_F3, 3)
#define S5P_GPF3_3_IN			(0x0)
#define S5P_GPF3_3_OUT			(0x1)
#define S5P_GPF3_3_LCD_VD23		(0x2)
#define S5P_GPF3_3_SYS_OE		(0x3)
#define S5P_GPF3_3_VEN_FIELD		(0x4)
#define S5P_GPF3_3_EXT_INT11_3		(0xF)

/* GPG0 */
#define S5P_GPG0_CON			S5P_GPIO_REG(0x160)
#define S5P_GPG0_DAT			S5P_GPIO_REG(0x164)
#define S5P_GPG0_PUD			S5P_GPIO_REG(0x168)
#define S5P_GPG0_DRV			S5P_GPIO_REG(0x16C)
#define S5P_GPG0_CONPDN			S5P_GPIO_REG(0x170)
#define S5P_GPG0_PUDPDN			S5P_GPIO_REG(0x174)

#define S5P_GPG0_0			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 0)
#define S5P_GPG0_0_IN			(0x0)
#define S5P_GPG0_0_OUT			(0x1)
#define S5P_GPG0_0_SD0_CLK		(0x2)
#define S5P_GPG0_0_EXT_INT12_0		(0xF)

#define S5P_GPG0_1			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 1)
#define S5P_GPG0_1_IN			(0x0)
#define S5P_GPG0_1_OUT			(0x1)
#define S5P_GPG0_1_SD0_CMD		(0x2)
#define S5P_GPG0_1_EXT_INT12_1		(0xF)

#define S5P_GPG0_2			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 2)
#define S5P_GPG0_2_IN			(0x0)
#define S5P_GPG0_2_OUT			(0x1)
#define S5P_GPG0_2_SD0_DATA0		(0x2)
#define S5P_GPG0_2_EXT_INT12_2		(0xF)

#define S5P_GPG0_3			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 3)
#define S5P_GPG0_3_IN			(0x0)
#define S5P_GPG0_3_OUT			(0x1)
#define S5P_GPG0_3_SD0_DATA1		(0x2)
#define S5P_GPG0_3_EXT_INT12_3		(0xF)

#define S5P_GPG0_4			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 4)
#define S5P_GPG0_4_IN			(0x0)
#define S5P_GPG0_4_OUT			(0x1)
#define S5P_GPG0_4_SD0_DATA2		(0x2)
#define S5P_GPG0_4_EXT_INT12_4		(0xF)

#define S5P_GPG0_5			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 5)
#define S5P_GPG0_5_IN			(0x0)
#define S5P_GPG0_5_OUT			(0x1)
#define S5P_GPG0_5_SD0_DATA3		(0x2)
#define S5P_GPG0_5_EXT_INT12_5		(0xF)

#define S5P_GPG0_6			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 6)
#define S5P_GPG0_6_IN			(0x0)
#define S5P_GPG0_6_OUT			(0x1)
#define S5P_GPG0_6_SD0_DATA4		(0x2)
#define S5P_GPG0_6_EXT_INT12_6		(0xF)

#define S5P_GPG0_7			S5P_GPIO_NO(S5P_GPIO_BANK_G0, 7)
#define S5P_GPG0_7_IN			(0x0)
#define S5P_GPG0_7_OUT			(0x1)
#define S5P_GPG0_7_SD0_DATA5		(0x2)
#define S5P_GPG0_7_EXT_INT12_7		(0xF)

/* GPG1 */
#define S5P_GPG1_CON			S5P_GPIO_REG(0x180)
#define S5P_GPG1_DAT			S5P_GPIO_REG(0x184)
#define S5P_GPG1_PUD			S5P_GPIO_REG(0x188)
#define S5P_GPG1_DRV			S5P_GPIO_REG(0x18C)
#define S5P_GPG1_CONPDN			S5P_GPIO_REG(0x190)
#define S5P_GPG1_PUDPDN			S5P_GPIO_REG(0x194)

#define S5P_GPG1_0			S5P_GPIO_NO(S5P_GPIO_BANK_G1, 0)
#define S5P_GPG1_0_IN			(0x0)
#define S5P_GPG1_0_OUT			(0x1)
#define S5P_GPG1_0_SD0_DATA6		(0x2)
#define S5P_GPG1_0_EXT_INT13_0		(0xF)

#define S5P_GPG1_1			S5P_GPIO_NO(S5P_GPIO_BANK_G1, 1)
#define S5P_GPG1_1_IN			(0x0)
#define S5P_GPG1_1_OUT			(0x1)
#define S5P_GPG1_1_SD0_DATA7		(0x2)
#define S5P_GPG1_1_EXT_INT13_1		(0xF)

#define S5P_GPG1_2			S5P_GPIO_NO(S5P_GPIO_BANK_G1, 2)
#define S5P_GPG1_2_IN			(0x0)
#define S5P_GPG1_2_OUT			(0x1)
#define S5P_GPG1_2_SD0_CDn		(0x2)
#define S5P_GPG1_2_EXT_INT13_2		(0xF)

/* GPG2 */
#define S5P_GPG2_CON			S5P_GPIO_REG(0x1A0)
#define S5P_GPG2_DAT			S5P_GPIO_REG(0x1A4)
#define S5P_GPG2_PUD			S5P_GPIO_REG(0x1A8)
#define S5P_GPG2_DRV			S5P_GPIO_REG(0x1AC)
#define S5P_GPG2_CONPDN			S5P_GPIO_REG(0x1B0)
#define S5P_GPG2_PUDPDN			S5P_GPIO_REG(0x1B4)

#define S5P_GPG2_0			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 0)
#define S5P_GPG2_0_IN			(0x0)
#define S5P_GPG2_0_OUT			(0x1)
#define S5P_GPG2_0_SD1_CLK		(0x2)
#define S5P_GPG2_0_EXT_INT14_0		(0xF)

#define S5P_GPG2_1			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 1)
#define S5P_GPG2_1_IN			(0x0)
#define S5P_GPG2_1_OUT			(0x1)
#define S5P_GPG2_1_SD1_CMD		(0x2)
#define S5P_GPG2_1_EXT_INT14_1		(0xF)

#define S5P_GPG2_2			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 2)
#define S5P_GPG2_2_IN			(0x0)
#define S5P_GPG2_2_OUT			(0x1)
#define S5P_GPG2_2_SD1_DATA0		(0x2)
#define S5P_GPG2_2_EXT_INT14_2		(0xF)

#define S5P_GPG2_3			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 3)
#define S5P_GPG2_3_IN			(0x0)
#define S5P_GPG2_3_OUT			(0x1)
#define S5P_GPG2_3_SD1_DATA1		(0x2)
#define S5P_GPG2_3_EXT_INT14_3		(0xF)

#define S5P_GPG2_4			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 4)
#define S5P_GPG2_4_IN			(0x0)
#define S5P_GPG2_4_OUT			(0x1)
#define S5P_GPG2_4_SD1_DATA2		(0x2)
#define S5P_GPG2_4_EXT_INT14_4		(0xF)

#define S5P_GPG2_5			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 5)
#define S5P_GPG2_5_IN			(0x0)
#define S5P_GPG2_5_OUT			(0x1)
#define S5P_GPG2_5_SD1_DATA3		(0x2)
#define S5P_GPG2_5_EXT_INT14_5		(0xF)

#define S5P_GPG2_6			S5P_GPIO_NO(S5P_GPIO_BANK_G2, 6)
#define S5P_GPG2_6_IN			(0x0)
#define S5P_GPG2_6_OUT			(0x1)
#define S5P_GPG2_6_SD1_CDn		(0x2)
#define S5P_GPG2_6_EXT_INT14_6		(0xF)

/* GPG3 */
#define S5P_GPG3_CON			S5P_GPIO_REG(0x1C0)
#define S5P_GPG3_DAT			S5P_GPIO_REG(0x1C4)
#define S5P_GPG3_PUD			S5P_GPIO_REG(0x1C8)
#define S5P_GPG3_DRV			S5P_GPIO_REG(0x1CC)
#define S5P_GPG3_CONPDN			S5P_GPIO_REG(0x1D0)
#define S5P_GPG3_PUDPDN			S5P_GPIO_REG(0x1D4)

#define S5P_GPG3_0			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 0)
#define S5P_GPG3_0_IN			(0x0)
#define S5P_GPG3_0_OUT			(0x1)
#define S5P_GPG3_0_SD2_CLK		(0x2)
#define S5P_GPG3_0_SPI2_CLK		(0x3)
#define S5P_GPG3_0_I2S2_SCLK		(0x4)
#define S5P_GPG3_0_PCM0_SCLK		(0x5)
#define S5P_GPG3_0_EXT_INT15_0		(0xF)

#define S5P_GPG3_1			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 1)
#define S5P_GPG3_1_IN			(0x0)
#define S5P_GPG3_1_OUT			(0x1)
#define S5P_GPG3_1_SD2_CMD		(0x2)
#define S5P_GPG3_1_SPI2_nSS		(0x3)
#define S5P_GPG3_1_I2S2_CDCLK		(0x4)
#define S5P_GPG3_1_PCM0_EXTCLK		(0x5)
#define S5P_GPG3_1_EXT_INT15_1		(0xF)

#define S5P_GPG3_2			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 2)
#define S5P_GPG3_2_IN			(0x0)
#define S5P_GPG3_2_OUT			(0x1)
#define S5P_GPG3_2_SD2_DATA0		(0x2)
#define S5P_GPG3_2_SPI2_MISO		(0x3)
#define S5P_GPG3_2_I2S2_LRCK		(0x4)
#define S5P_GPG3_2_PCM0_FSYNC		(0x5)
#define S5P_GPG3_2_EXT_INT15_2		(0xF)

#define S5P_GPG3_3			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 3)
#define S5P_GPG3_3_IN			(0x0)
#define S5P_GPG3_3_OUT			(0x1)
#define S5P_GPG3_3_SD2_DATA1		(0x2)
#define S5P_GPG3_3_SPI2_MOSI		(0x3)
#define S5P_GPG3_3_I2S2_SDI		(0x4)
#define S5P_GPG3_3_PCM0_SIN		(0x5)
#define S5P_GPG3_3_EXT_INT15_3		(0xF)

#define S5P_GPG3_4			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 4)
#define S5P_GPG3_4_IN			(0x0)
#define S5P_GPG3_4_OUT			(0x1)
#define S5P_GPG3_4_SD2_DATA2		(0x2)
#define S5P_GPG3_4_I2S2_SDO		(0x4)
#define S5P_GPG3_4_PCM0_SOUT		(0x5)
#define S5P_GPG3_4_EXT_INT15_4		(0xF)

#define S5P_GPG3_5			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 5)
#define S5P_GPG3_5_IN			(0x0)
#define S5P_GPG3_5_OUT			(0x1)
#define S5P_GPG3_5_SD2_DATA3		(0x2)
#define S5P_GPG3_5_SPDIF0_OUT		(0x5)
#define S5P_GPG3_5_EXT_INT15_5		(0xF)

#define S5P_GPG3_6			S5P_GPIO_NO(S5P_GPIO_BANK_G3, 6)
#define S5P_GPG3_6_IN			(0x0)
#define S5P_GPG3_6_OUT			(0x1)
#define S5P_GPG3_6_SD2_CDn		(0x2)
#define S5P_GPG3_6_SPDIF_EXTCLK		(0x5)
#define S5P_GPG3_6_EXT_INT15_6		(0xF)

/* GPH0 */
#define S5P_GPH0_CON			S5P_GPIO_REG(0xC00)
#define S5P_GPH0_DAT			S5P_GPIO_REG(0xC04)
#define S5P_GPH0_PUD			S5P_GPIO_REG(0xC08)
#define S5P_GPH0_DRV			S5P_GPIO_REG(0xC0C)
#define S5P_GPH0_CONPDN			S5P_GPIO_REG(0xC10)
#define S5P_GPH0_PUDPDN			S5P_GPIO_REG(0xC14)

#define S5P_GPH0_0			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 0)
#define S5P_GPH0_0_IN			(0x0)
#define S5P_GPH0_0_OUT			(0x1)
#define S5P_GPH0_0_EXT_INT_0		(0x2)

#define S5P_GPH0_1			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 1)
#define S5P_GPH0_1_IN			(0x0)
#define S5P_GPH0_1_OUT			(0x1)
#define S5P_GPH0_1_EXT_INT_1		(0x2)

#define S5P_GPH0_2			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 2)
#define S5P_GPH0_2_IN			(0x0)
#define S5P_GPH0_2_OUT			(0x1)
#define S5P_GPH0_2_EXT_INT_2		(0x2)

#define S5P_GPH0_3			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 3)
#define S5P_GPH0_3_IN			(0x0)
#define S5P_GPH0_3_OUT			(0x1)
#define S5P_GPH0_3_EXT_INT_3		(0x2)

#define S5P_GPH0_4			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 4)
#define S5P_GPH0_4_IN			(0x0)
#define S5P_GPH0_4_OUT			(0x1)
#define S5P_GPH0_4_EXT_INT_4		(0x2)

#define S5P_GPH0_5			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 5)
#define S5P_GPH0_5_IN			(0x0)
#define S5P_GPH0_5_OUT			(0x1)
#define S5P_GPH0_5_EXT_INT_5		(0x2)

#define S5P_GPH0_6			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 6)
#define S5P_GPH0_6_IN			(0x0)
#define S5P_GPH0_6_OUT			(0x1)
#define S5P_GPH0_6_EXT_INT_6		(0x2)

#define S5P_GPH0_7			S5P_GPIO_NO(S5P_GPIO_BANK_H0, 7)
#define S5P_GPH0_7_IN			(0x0)
#define S5P_GPH0_7_OUT			(0x1)
#define S5P_GPH0_7_EXT_INT_7		(0x2)

/* GPH1 */
#define S5P_GPH1_CON			S5P_GPIO_REG(0xC20)
#define S5P_GPH1_DAT			S5P_GPIO_REG(0xC24)
#define S5P_GPH1_PUD			S5P_GPIO_REG(0xC28)
#define S5P_GPH1_DRV			S5P_GPIO_REG(0xC2C)
 
#define S5P_GPH1_0			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 0)
#define S5P_GPH1_0_IN			(0x0)
#define S5P_GPH1_0_OUT			(0x1)
#define S5P_GPH1_0_EXT_INT_8		(0x2)

#define S5P_GPH1_1			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 1)
#define S5P_GPH1_1_IN			(0x0)
#define S5P_GPH1_1_OUT			(0x1)
#define S5P_GPH1_1_EXT_INT_9		(0x2)

#define S5P_GPH1_2			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 2)
#define S5P_GPH1_2_IN			(0x0)
#define S5P_GPH1_2_OUT			(0x1)
#define S5P_GPH1_2_EXT_INT_10		(0x2)
#define S5P_GPH1_2_CG_REALIN		(0x3)

#define S5P_GPH1_3			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 3)
#define S5P_GPH1_3_IN			(0x0)
#define S5P_GPH1_3_OUT			(0x1)
#define S5P_GPH1_3_EXT_INT_11		(0x2)
#define S5P_GPH1_3_CG_IMGIN		(0x3)

#define S5P_GPH1_4			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 4)
#define S5P_GPH1_4_IN			(0x0)
#define S5P_GPH1_4_OUT			(0x1)
#define S5P_GPH1_4_EXT_INT_12		(0x2)
#define S5P_GPH1_4_CG_GPO0		(0x3)

#define S5P_GPH1_5			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 5)
#define S5P_GPH1_5_IN			(0x0)
#define S5P_GPH1_5_OUT			(0x1)
#define S5P_GPH1_5_EXT_INT_13		(0x2)
#define S5P_GPH1_5_CG_GPO1		(0x3)

#define S5P_GPH1_6			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 6)
#define S5P_GPH1_6_IN			(0x0)
#define S5P_GPH1_6_OUT			(0x1)
#define S5P_GPH1_6_EXT_INT_14		(0x2)
#define S5P_GPH1_6_CG_GPO2		(0x3)

#define S5P_GPH1_7			S5P_GPIO_NO(S5P_GPIO_BANK_H1, 7)
#define S5P_GPH1_7_IN			(0x0)
#define S5P_GPH1_7_OUT			(0x1)
#define S5P_GPH1_7_EXT_INT_15		(0x2)
#define S5P_GPH1_7_CG_GPO3		(0x3)

/* GPH2 */
#define S5P_GPH2_CON			S5P_GPIO_REG(0xC40)
#define S5P_GPH2_DAT			S5P_GPIO_REG(0xC44)
#define S5P_GPH2_PUD			S5P_GPIO_REG(0xC48)
#define S5P_GPH2_DRV			S5P_GPIO_REG(0xC4C)

#define S5P_GPH2_0			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 0)
#define S5P_GPH2_0_IN			(0x0)
#define S5P_GPH2_0_OUT			(0x1)
#define S5P_GPH2_0_EXT_INT_16		(0x2)
#define S5P_GPH2_0_KP_COL0		(0x3)
#define S5P_GPH2_0_CAM_B_DATA0		(0x4)

#define S5P_GPH2_1			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 1)
#define S5P_GPH2_1_IN			(0x0)
#define S5P_GPH2_1_OUT			(0x1)
#define S5P_GPH2_1_EXT_INT_17		(0x2)
#define S5P_GPH2_1_KP_COL1		(0x3)
#define S5P_GPH2_1_CAM_B_DATA1		(0x4)

#define S5P_GPH2_2			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 2)
#define S5P_GPH2_2_IN			(0x0)
#define S5P_GPH2_2_OUT			(0x1)
#define S5P_GPH2_2_EXT_INT_18		(0x2)
#define S5P_GPH2_2_KP_COL2		(0x3)
#define S5P_GPH2_2_CAM_B_DATA2		(0x4)

#define S5P_GPH2_3			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 3)
#define S5P_GPH2_3_IN			(0x0)
#define S5P_GPH2_3_OUT			(0x1)
#define S5P_GPH2_3_EXT_INT_19		(0x2)
#define S5P_GPH2_3_KP_COL3		(0x3)
#define S5P_GPH2_3_CAM_B_DATA3		(0x4)

#define S5P_GPH2_4			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 4)
#define S5P_GPH2_4_IN			(0x0)
#define S5P_GPH2_4_OUT			(0x1)
#define S5P_GPH2_4_EXT_INT_20		(0x2)
#define S5P_GPH2_4_KP_COL4		(0x3)
#define S5P_GPH2_4_CAM_B_DATA4		(0x4)

#define S5P_GPH2_5			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 5)
#define S5P_GPH2_5_IN			(0x0)
#define S5P_GPH2_5_OUT			(0x1)
#define S5P_GPH2_5_EXT_INT_21		(0x2)
#define S5P_GPH2_5_KP_COL5		(0x3)
#define S5P_GPH2_5_CAM_B_DATA5		(0x4)

#define S5P_GPH2_6			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 6)
#define S5P_GPH2_6_IN			(0x0)
#define S5P_GPH2_6_OUT			(0x1)
#define S5P_GPH2_6_EXT_INT_22		(0x2)
#define S5P_GPH2_6_KP_COL6		(0x3)
#define S5P_GPH2_6_CAM_B_DATA6		(0x4)

#define S5P_GPH2_7			S5P_GPIO_NO(S5P_GPIO_BANK_H2, 7)
#define S5P_GPH2_7_IN			(0x0)
#define S5P_GPH2_7_OUT			(0x1)
#define S5P_GPH2_7_EXT_INT_23		(0x2)
#define S5P_GPH2_7_KP_COL7		(0x3)
#define S5P_GPH2_7_CAM_B_DATA7		(0x4)

/* GPH3 */
#define S5P_GPH3_CON			S5P_GPIO_REG(0xC60)
#define S5P_GPH3_DAT			S5P_GPIO_REG(0xC64)
#define S5P_GPH3_PUD			S5P_GPIO_REG(0xC68)
#define S5P_GPH3_DRV			S5P_GPIO_REG(0xC6C)
 
#define S5P_GPH3_0			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 0)
#define S5P_GPH3_0_IN			(0x0)
#define S5P_GPH3_0_OUT			(0x1)
#define S5P_GPH3_0_EXT_INT_24		(0x2)
#define S5P_GPH3_0_KP_ROW0		(0x3)
#define S5P_GPH3_0_CAM_B_PCLK		(0x4)

#define S5P_GPH3_1			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 1)
#define S5P_GPH3_1_IN			(0x0)
#define S5P_GPH3_1_OUT			(0x1)
#define S5P_GPH3_1_EXT_INT_25		(0x2)
#define S5P_GPH3_1_KP_ROW1		(0x3)
#define S5P_GPH3_1_CAM_B_VSYNC		(0x4)

#define S5P_GPH3_2			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 2)
#define S5P_GPH3_2_IN			(0x0)
#define S5P_GPH3_2_OUT			(0x1)
#define S5P_GPH3_2_EXT_INT_26		(0x2)
#define S5P_GPH3_2_KP_ROW2		(0x3)
#define S5P_GPH3_2_CAM_B_HREF		(0x4)

#define S5P_GPH3_3			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 3)
#define S5P_GPH3_3_IN			(0x0)
#define S5P_GPH3_3_OUT			(0x1)
#define S5P_GPH3_3_EXT_INT_27		(0x2)
#define S5P_GPH3_3_KP_ROW3		(0x3)
#define S5P_GPH3_3_CAM_B_FIELD		(0x4)

#define S5P_GPH3_4			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 4)
#define S5P_GPH3_4_IN			(0x0)
#define S5P_GPH3_4_OUT			(0x1)
#define S5P_GPH3_4_EXT_INT_28		(0x2)
#define S5P_GPH3_4_KP_ROW4		(0x3)
#define S5P_GPH3_4_CAN0_TX		(0x4)

#define S5P_GPH3_5			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 5)
#define S5P_GPH3_5_IN			(0x0)
#define S5P_GPH3_5_OUT			(0x1)
#define S5P_GPH3_5_EXT_INT_29		(0x2)
#define S5P_GPH3_5_KP_ROW5		(0x3)
#define S5P_GPH3_5_CAN0_RX		(0x4)

#define S5P_GPH3_6			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 6)
#define S5P_GPH3_6_IN			(0x0)
#define S5P_GPH3_6_OUT			(0x1)
#define S5P_GPH3_6_EXT_INT_30		(0x2)
#define S5P_GPH3_6_KP_ROW6		(0x3)
#define S5P_GPH3_6_CAN1_TX		(0x4)

#define S5P_GPH3_7			S5P_GPIO_NO(S5P_GPIO_BANK_H3, 6)
#define S5P_GPH3_7_IN			(0x0)
#define S5P_GPH3_7_OUT			(0x1)
#define S5P_GPH3_7_EXT_INT_31		(0x2)
#define S5P_GPH3_7_KP_ROW7		(0x3)
#define S5P_GPH3_7_CAN1_RX		(0x4)

/* GPI */
#define S5P_GPI0_CON			S5P_GPIO_REG(0x1E0)
#define S5P_GPI0_DAT			S5P_GPIO_REG(0x1E4)
#define S5P_GPI0_PUD			S5P_GPIO_REG(0x1E8)
#define S5P_GPI0_DRV			S5P_GPIO_REG(0x1EC)
#define S5P_GPI0_CONPDN			S5P_GPIO_REG(0x1F0)
#define S5P_GPI0_PUDPDN			S5P_GPIO_REG(0x1F4)

#define S5P_GPI0			S5P_GPIO_NO(S5P_GPIO_BANK_I, 0)
#define S5P_GPI0_IN			(0x0)
#define S5P_GPI0_OUT			(0x1)
#define S5P_GPI0_IEM_SCLK		(0x2)
#define S5P_GPI0_EXT_INT20_0		(0xF)

#define S5P_GPI1			S5P_GPIO_NO(S5P_GPIO_BANK_I, 1)
#define S5P_GPI1_IN			(0x0)
#define S5P_GPI1_OUT			(0x1)
#define S5P_GPI1_IEM_SPWI		(0x2)
#define S5P_GPI1_EXT_INT20_1		(0xF)

#define S5P_GPI2			S5P_GPIO_NO(S5P_GPIO_BANK_I, 2)
#define S5P_GPI3			S5P_GPIO_NO(S5P_GPIO_BANK_I, 3)

#define S5P_GPI4			S5P_GPIO_NO(S5P_GPIO_BANK_I, 4)
#define S5P_GPI4_IN			(0x0)
#define S5P_GPI4_OUT			(0x1)
#define S5P_GPI4_NFMOD2			(0x2)
#define S5P_GPI4_EXT_INT20_4		(0xF)

#define S5P_GPI5			S5P_GPIO_NO(S5P_GPIO_BANK_I, 5)
#define S5P_GPI5_IN			(0x0)
#define S5P_GPI5_OUT			(0x1)
#define S5P_GPI5_NFMOD3			(0x2)
#define S5P_GPI5_EXT_INT20_5		(0xF)

#define S5P_GPI6			S5P_GPIO_NO(S5P_GPIO_BANK_I, 6)
#define S5P_GPI6_IN			(0x0)
#define S5P_GPI6_OUT			(0x1)
#define S5P_GPI6_NFMOD4			(0x2)
#define S5P_GPI6_EXT_INT20_6		(0xF)

#define S5P_GPI7			S5P_GPIO_NO(S5P_GPIO_BANK_I, 7)
#define S5P_GPI7_IN			(0x0)
#define S5P_GPI7_OUT			(0x1)
#define S5P_GPI7_NFMOD5			(0x2)
#define S5P_GPI7_EXT_INT20_7		(0xF)

/* GPJ0 */
#define S5P_GPJ0_CON			S5P_GPIO_REG(0x200)
#define S5P_GPJ0_DAT			S5P_GPIO_REG(0x204)
#define S5P_GPJ0_PUD			S5P_GPIO_REG(0x208)
#define S5P_GPJ0_DRV			S5P_GPIO_REG(0x20C)
#define S5P_GPJ0_CONPDN			S5P_GPIO_REG(0x210)
#define S5P_GPJ0_PUDPDN			S5P_GPIO_REG(0x214)

#define S5P_GPJ0_0			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 0)
#define S5P_GPJ0_0_IN			(0x0)
#define S5P_GPJ0_0_OUT			(0x1)
#define S5P_GPJ0_0_MSM_ADDR0		(0x2)
#define S5P_GPJ0_0_HSI_TX_DATA		(0x3)
#define S5P_GPJ0_0_CF_ADDR0		(0x4)
#define S5P_GPJ0_0_LCD1_HSYNC		(0x5)
#define S5P_GPJ0_0_EXT_INT21_0		(0xF)

#define S5P_GPJ0_1			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 1)
#define S5P_GPJ0_1_IN			(0x0)
#define S5P_GPJ0_1_OUT			(0x1)
#define S5P_GPJ0_1_MSM_ADDR1		(0x2)
#define S5P_GPJ0_1_HSI_TX_FLAG		(0x3)
#define S5P_GPJ0_1_CF_ADDR1		(0x4)
#define S5P_GPJ0_1_LCD1_VSYNC		(0x5)
#define S5P_GPJ0_1_EXT_INT21_1		(0xF)

#define S5P_GPJ0_2			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 2)
#define S5P_GPJ0_2_IN			(0x0)
#define S5P_GPJ0_2_OUT			(0x1)
#define S5P_GPJ0_2_MSM_ADDR2		(0x2)
#define S5P_GPJ0_2_HSI_TX_WAKE		(0x3)
#define S5P_GPJ0_2_CF_ADDR2		(0x4)
#define S5P_GPJ0_2_LCD1_VDEN		(0x5)
#define S5P_GPJ0_2_EXT_INT21_2		(0xF)

#define S5P_GPJ0_3			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 3)
#define S5P_GPJ0_3_IN			(0x0)
#define S5P_GPJ0_3_OUT			(0x1)
#define S5P_GPJ0_3_MSM_ADDR3		(0x2)
#define S5P_GPJ0_3_HSI_TX_READY		(0x3)
#define S5P_GPJ0_3_CF_IORDY		(0x4)
#define S5P_GPJ0_3_LCD1_VCLK		(0x5)
#define S5P_GPJ0_3_EXT_INT21_3		(0xF)

#define S5P_GPJ0_4			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 4)
#define S5P_GPJ0_4_IN			(0x0)
#define S5P_GPJ0_4_OUT			(0x1)
#define S5P_GPJ0_4_MSM_ADDR4		(0x2)
#define S5P_GPJ0_4_HSI_RX_DATA		(0x3)
#define S5P_GPJ0_4_CF_INTRQ		(0x4)
#define S5P_GPJ0_4_LCD1_VD0		(0x5)
#define S5P_GPJ0_4_EXT_INT21_4		(0xF)

#define S5P_GPJ0_5			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 5)
#define S5P_GPJ0_5_IN			(0x0)
#define S5P_GPJ0_5_OUT			(0x1)
#define S5P_GPJ0_5_MSM_ADDR5		(0x2)
#define S5P_GPJ0_5_HSI_RX_FLAG		(0x3)
#define S5P_GPJ0_5_CF_INPACKn		(0x4)
#define S5P_GPJ0_5_LCD1_VD1		(0x5)
#define S5P_GPJ0_5_EXT_INT21_5		(0xF)

#define S5P_GPJ0_6			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 6)
#define S5P_GPJ0_6_IN			(0x0)
#define S5P_GPJ0_6_OUT			(0x1)
#define S5P_GPJ0_6_MSM_ADDR6		(0x2)
#define S5P_GPJ0_6_HSI_RX_WAKE		(0x3)
#define S5P_GPJ0_6_CF_RESET		(0x4)
#define S5P_GPJ0_6_LCD1_VD2		(0x5)
#define S5P_GPJ0_6_EXT_INT21_6		(0xF)

#define S5P_GPJ0_7			S5P_GPIO_NO(S5P_GPIO_BANK_J0, 7)
#define S5P_GPJ0_7_IN			(0x0)
#define S5P_GPJ0_7_OUT			(0x1)
#define S5P_GPJ0_7_MSM_ADDR7		(0x2)
#define S5P_GPJ0_7_HSI_RX_READY		(0x3)
#define S5P_GPJ0_7_CF_REG		(0x4)
#define S5P_GPJ0_7_LCD1_VD3		(0x5)
#define S5P_GPJ0_7_EXT_INT21_7		(0xF)

/* GPJ1 */
#define S5P_GPJ1_CON			S5P_GPIO_REG(0x220)
#define S5P_GPJ1_DAT			S5P_GPIO_REG(0x224)
#define S5P_GPJ1_PUD			S5P_GPIO_REG(0x228)
#define S5P_GPJ1_DRV			S5P_GPIO_REG(0x22C)
#define S5P_GPJ1_CONPDN			S5P_GPIO_REG(0x230)
#define S5P_GPJ1_PUDPDN			S5P_GPIO_REG(0x234)

#define S5P_GPJ1_0			S5P_GPIO_NO(S5P_GPIO_BANK_J1, 0)
#define S5P_GPJ1_0_IN			(0x0)
#define S5P_GPJ1_0_OUT			(0x1)
#define S5P_GPJ1_0_MSM_ADDR8		(0x2)
#define S5P_GPJ1_0_LCD1_VD4		(0x5)
#define S5P_GPJ1_0_EXT_INT22_0		(0xF)

#define S5P_GPJ1_1			S5P_GPIO_NO(S5P_GPIO_BANK_J1, 1)
#define S5P_GPJ1_1_IN			(0x0)
#define S5P_GPJ1_1_OUT			(0x1)
#define S5P_GPJ1_1_MSM_ADDR9		(0x2)
#define S5P_GPJ1_1_LCD1_VD5		(0x5)
#define S5P_GPJ1_1_EXT_INT22_1		(0xF)

#define S5P_GPJ1_2			S5P_GPIO_NO(S5P_GPIO_BANK_J1, 2)
#define S5P_GPJ1_2_IN			(0x0)
#define S5P_GPJ1_2_OUT			(0x1)
#define S5P_GPJ1_2_MSM_ADDR10		(0x2)
#define S5P_GPJ1_2_LCD1_VD6		(0x5)
#define S5P_GPJ1_2_EXT_INT22_2		(0xF)

#define S5P_GPJ1_3			S5P_GPIO_NO(S5P_GPIO_BANK_J1, 3)
#define S5P_GPJ1_3_IN			(0x0)
#define S5P_GPJ1_3_OUT			(0x1)
#define S5P_GPJ1_3_MSM_ADDR11		(0x2)
#define S5P_GPJ1_3_LCD1_VD7		(0x5)
#define S5P_GPJ1_3_EXT_INT22_3		(0xF)

#define S5P_GPJ1_4			S5P_GPIO_NO(S5P_GPIO_BANK_J1, 4)
#define S5P_GPJ1_4_IN			(0x0)
#define S5P_GPJ1_4_OUT			(0x1)
#define S5P_GPJ1_4_MSM_ADDR12		(0x2)
#define S5P_GPJ1_4_LCD1_VD8		(0x5)
#define S5P_GPJ1_4_EXT_INT22_4		(0xF)

/* GPJ2 */
#define S5P_GPJ2_CON			S5P_GPIO_REG(0x240)
#define S5P_GPJ2_DAT			S5P_GPIO_REG(0x244)
#define S5P_GPJ2_PUD			S5P_GPIO_REG(0x248)
#define S5P_GPJ2_DRV			S5P_GPIO_REG(0x24C)
#define S5P_GPJ2_CONPDN			S5P_GPIO_REG(0x250)
#define S5P_GPJ2_PUDPDN			S5P_GPIO_REG(0x254)

#define S5P_GPJ2_0			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 0)
#define S5P_GPJ2_0_IN			(0x0)
#define S5P_GPJ2_0_OUT			(0x1)
#define S5P_GPJ2_0_MSM_DATA0		(0x2)
#define S5P_GPJ2_0_CF_DATA0		(0x4)
#define S5P_GPJ2_0_LCD1_VD9		(0x5)
#define S5P_GPJ2_0_EXT_INT23_0		(0xF)

#define S5P_GPJ2_1			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 1)
#define S5P_GPJ2_1_IN			(0x0)
#define S5P_GPJ2_1_OUT			(0x1)
#define S5P_GPJ2_1_MSM_DATA1		(0x2)
#define S5P_GPJ2_1_CF_DATA1		(0x4)
#define S5P_GPJ2_1_LCD1_VD10		(0x5)
#define S5P_GPJ2_1_EXT_INT23_1		(0xF)

#define S5P_GPJ2_2			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 2)
#define S5P_GPJ2_2_IN			(0x0)
#define S5P_GPJ2_2_OUT			(0x1)
#define S5P_GPJ2_2_MSM_DATA2		(0x2)
#define S5P_GPJ2_2_CF_DATA2		(0x4)
#define S5P_GPJ2_2_LCD1_VD11		(0x5)
#define S5P_GPJ2_2_EXT_INT23_2		(0xF)

#define S5P_GPJ2_3			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 3)
#define S5P_GPJ2_3_IN			(0x0)
#define S5P_GPJ2_3_OUT			(0x1)
#define S5P_GPJ2_3_MSM_DATA3		(0x2)
#define S5P_GPJ2_3_CF_DATA3		(0x4)
#define S5P_GPJ2_3_LCD1_VD12		(0x5)
#define S5P_GPJ2_3_EXT_INT23_3		(0xF)

#define S5P_GPJ2_4			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 4)
#define S5P_GPJ2_4_IN			(0x0)
#define S5P_GPJ2_4_OUT			(0x1)
#define S5P_GPJ2_4_MSM_DATA4		(0x2)
#define S5P_GPJ2_4_CF_DATA4		(0x4)
#define S5P_GPJ2_4_LCD1_VD13		(0x5)
#define S5P_GPJ2_4_EXT_INT23_4		(0xF)

#define S5P_GPJ2_5			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 5)
#define S5P_GPJ2_5_IN			(0x0)
#define S5P_GPJ2_5_OUT			(0x1)
#define S5P_GPJ2_5_MSM_DATA5		(0x2)
#define S5P_GPJ2_5_CF_DATA5		(0x4)
#define S5P_GPJ2_5_LCD1_VD14		(0x5)
#define S5P_GPJ2_5_EXT_INT23_5		(0xF)

#define S5P_GPJ2_6			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 6)
#define S5P_GPJ2_6_IN			(0x0)
#define S5P_GPJ2_6_OUT			(0x1)
#define S5P_GPJ2_6_MSM_DATA6		(0x2)
#define S5P_GPJ2_6_CF_DATA6		(0x4)
#define S5P_GPJ2_6_LCD1_VD15		(0x5)
#define S5P_GPJ2_6_EXT_INT23_6		(0xF)

#define S5P_GPJ2_7			S5P_GPIO_NO(S5P_GPIO_BANK_J2, 7)
#define S5P_GPJ2_7_IN			(0x0)
#define S5P_GPJ2_7_OUT			(0x1)
#define S5P_GPJ2_7_MSM_DATA7		(0x2)
#define S5P_GPJ2_7_CF_DATA7		(0x4)
#define S5P_GPJ2_7_LCD1_VD16		(0x5)
#define S5P_GPJ2_7_EXT_INT23_7		(0xF)

/* GPJ3 */
#define S5P_GPJ3_CON			S5P_GPIO_REG(0x260)
#define S5P_GPJ3_DAT			S5P_GPIO_REG(0x264)
#define S5P_GPJ3_PUD			S5P_GPIO_REG(0x268)
#define S5P_GPJ3_DRV			S5P_GPIO_REG(0x26C)
#define S5P_GPJ3_CONPDN			S5P_GPIO_REG(0x270)
#define S5P_GPJ3_PUDPDN			S5P_GPIO_REG(0x274)

#define S5P_GPJ3_0			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 0)
#define S5P_GPJ3_0_IN			(0x0)
#define S5P_GPJ3_0_OUT			(0x1)
#define S5P_GPJ3_0_MSM_DATA8		(0x2)
#define S5P_GPJ3_0_CF_DATA8		(0x4)
#define S5P_GPJ3_0_LCD1_VD17		(0x5)
#define S5P_GPJ3_0_EXT_INT24_0		(0xF)

#define S5P_GPJ3_1			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 1)
#define S5P_GPJ3_1_IN			(0x0)
#define S5P_GPJ3_1_OUT			(0x1)
#define S5P_GPJ3_1_MSM_DATA9		(0x2)
#define S5P_GPJ3_1_CF_DATA9		(0x4)
#define S5P_GPJ3_1_LCD1_VD18		(0x5)
#define S5P_GPJ3_1_EXT_INT24_1		(0xF)

#define S5P_GPJ3_2			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 2)
#define S5P_GPJ3_2_IN			(0x0)
#define S5P_GPJ3_2_OUT			(0x1)
#define S5P_GPJ3_2_MSM_DATA10		(0x2)
#define S5P_GPJ3_2_CF_DATA10		(0x4)
#define S5P_GPJ3_2_LCD1_VD19		(0x5)
#define S5P_GPJ3_2_EXT_INT24_2		(0xF)

#define S5P_GPJ3_3			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 3)
#define S5P_GPJ3_3_IN			(0x0)
#define S5P_GPJ3_3_OUT			(0x1)
#define S5P_GPJ3_3_MSM_DATA11		(0x2)
#define S5P_GPJ3_3_CF_DATA11		(0x4)
#define S5P_GPJ3_3_LCD1_VD20		(0x5)
#define S5P_GPJ3_3_EXT_INT24_3		(0xF)

#define S5P_GPJ3_4			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 4)
#define S5P_GPJ3_4_IN			(0x0)
#define S5P_GPJ3_4_OUT			(0x1)
#define S5P_GPJ3_4_MSM_DATA12		(0x2)
#define S5P_GPJ3_4_CF_DATA12		(0x4)
#define S5P_GPJ3_4_LCD1_VD21		(0x5)
#define S5P_GPJ3_4_EXT_INT24_4		(0xF)

#define S5P_GPJ3_5			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 5)
#define S5P_GPJ3_5_IN			(0x0)
#define S5P_GPJ3_5_OUT			(0x1)
#define S5P_GPJ3_5_MSM_DATA13		(0x2)
#define S5P_GPJ3_5_CF_DATA13		(0x4)
#define S5P_GPJ3_5_LCD1_VD22		(0x5)
#define S5P_GPJ3_5_EXT_INT24_5		(0xF)

#define S5P_GPJ3_6			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 6)
#define S5P_GPJ3_6_IN			(0x0)
#define S5P_GPJ3_6_OUT			(0x1)
#define S5P_GPJ3_6_MSM_DATA14		(0x2)
#define S5P_GPJ3_6_CF_DATA14		(0x4)
#define S5P_GPJ3_6_LCD1_VD23		(0x5)
#define S5P_GPJ3_6_EXT_INT24_6		(0xF)

#define S5P_GPJ3_7			S5P_GPIO_NO(S5P_GPIO_BANK_J3, 7)
#define S5P_GPJ3_7_IN			(0x0)
#define S5P_GPJ3_7_OUT			(0x1)
#define S5P_GPJ3_7_MSM_DATA15		(0x2)
#define S5P_GPJ3_7_CF_DATA15		(0x4)
#define S5P_GPJ3_7_EXT_INT24_7		(0xF)

/* GPJ4 */
#define S5P_GPJ4_CON			S5P_GPIO_REG(0x280)
#define S5P_GPJ4_DAT			S5P_GPIO_REG(0x284)
#define S5P_GPJ4_PUD			S5P_GPIO_REG(0x288)
#define S5P_GPJ4_DRV			S5P_GPIO_REG(0x28C)
#define S5P_GPJ4_CONPDN			S5P_GPIO_REG(0x290)
#define S5P_GPJ4_PUDPDN			S5P_GPIO_REG(0x294)

#define S5P_GPJ4_0			S5P_GPIO_NO(S5P_GPIO_BANK_J4, 0)
#define S5P_GPJ4_0_IN			(0x0)
#define S5P_GPJ4_0_OUT			(0x1)
#define S5P_GPJ4_0_MSM_CSn		(0x2)
#define S5P_GPJ4_0_CF_CSn0		(0x4)
#define S5P_GPJ4_0_EXT_INT25_0		(0xF)

#define S5P_GPJ4_1			S5P_GPIO_NO(S5P_GPIO_BANK_J4, 1)
#define S5P_GPJ4_1_IN			(0x0)
#define S5P_GPJ4_1_OUT			(0x1)
#define S5P_GPJ4_1_MSM_WEn		(0x2)
#define S5P_GPJ4_1_CF_CSn1		(0x4)
#define S5P_GPJ4_1_EXT_INT25_1		(0xF)

#define S5P_GPJ4_2			S5P_GPIO_NO(S5P_GPIO_BANK_J4, 2)
#define S5P_GPJ4_2_IN			(0x0)
#define S5P_GPJ4_2_OUT			(0x1)
#define S5P_GPJ4_2_MSM_Rn		(0x2)
#define S5P_GPJ4_2_CF_IORD_CFn		(0x4)
#define S5P_GPJ4_2_EXT_INT25_2		(0xF)

#define S5P_GPJ4_3			S5P_GPIO_NO(S5P_GPIO_BANK_J4, 3)
#define S5P_GPJ4_3_IN			(0x0)
#define S5P_GPJ4_3_OUT			(0x1)
#define S5P_GPJ4_3_MSM_IRQn		(0x2)
#define S5P_GPJ4_3_CF_IOWR_CFn		(0x4)
#define S5P_GPJ4_3_EXT_INT25_3		(0xF)

/* GPK0 */
#define S5P_GPK0_CON			S5P_GPIO_REG(0x2A0)
#define S5P_GPK0_DAT			S5P_GPIO_REG(0x2A4)
#define S5P_GPK0_PUD			S5P_GPIO_REG(0x2A8)
#define S5P_GPK0_DRV			S5P_GPIO_REG(0x2AC)
#define S5P_GPK0_CONPDN			S5P_GPIO_REG(0x2B0)
#define S5P_GPK0_PUDPDN			S5P_GPIO_REG(0x2B4)

#define S5P_GPK0_0			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 0)
#define S5P_GPK0_0_IN			(0x0)
#define S5P_GPK0_0_OUT			(0x1)
#define S5P_GPK0_0_SROM_CSn0		(0x2)

#define S5P_GPK0_1			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 1)
#define S5P_GPK0_1_IN			(0x0)
#define S5P_GPK0_1_OUT			(0x1)
#define S5P_GPK0_1_SROM_CSn1		(0x2)

#define S5P_GPK0_2			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 2)
#define S5P_GPK0_2_IN			(0x0)
#define S5P_GPK0_2_OUT			(0x1)
#define S5P_GPK0_2_SROM_CSn2		(0x2)
#define S5P_GPK0_2_NF_CSn0		(0x3)
#define S5P_GPK0_2_ONENAND_CSn0		(0x5)

#define S5P_GPK0_3			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 3)
#define S5P_GPK0_3_IN			(0x0)
#define S5P_GPK0_3_OUT			(0x1)
#define S5P_GPK0_3_SROM_CSn3		(0x2)
#define S5P_GPK0_3_NF_CSn1		(0x3)
#define S5P_GPK0_3_ONENAND_CSn1		(0x5)

#define S5P_GPK0_4			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 4)
#define S5P_GPK0_4_IN			(0x0)
#define S5P_GPK0_4_OUT			(0x1)
#define S5P_GPK0_4_SROM_CSn4		(0x2)
#define S5P_GPK0_4_NF_CSn2		(0x3)
#define S5P_GPK0_4_CF_CSn0		(0x4)

#define S5P_GPK0_5			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 5)
#define S5P_GPK0_5_IN			(0x0)
#define S5P_GPK0_5_OUT			(0x1)
#define S5P_GPK0_5_SROM_CSn5		(0x2)
#define S5P_GPK0_5_NF_CSn3		(0x3)
#define S5P_GPK0_5_CF_CSn1		(0x4)

#define S5P_GPK0_6			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 6)
#define S5P_GPK0_6_IN			(0x0)
#define S5P_GPK0_6_OUT			(0x1)
#define S5P_GPK0_6_EBI_OEn		(0x2)

#define S5P_GPK0_7			S5P_GPIO_NO(S5P_GPIO_BANK_K0, 7)
#define S5P_GPK0_7_IN			(0x0)
#define S5P_GPK0_7_OUT			(0x1)
#define S5P_GPK0_7_EBI_WEn		(0x2)

/* GPK1 */
#define S5P_GPK1_CON			S5P_GPIO_REG(0x2C0)
#define S5P_GPK1_DAT			S5P_GPIO_REG(0x2C4)
#define S5P_GPK1_PUD			S5P_GPIO_REG(0x2C8)
#define S5P_GPK1_DRV			S5P_GPIO_REG(0x2CC)
#define S5P_GPK1_CONPDN			S5P_GPIO_REG(0x2D0)
#define S5P_GPK1_PUDPDN			S5P_GPIO_REG(0x2D4)

#define S5P_GPK1_0			S5P_GPIO_NO(S5P_GPIO_BANK_K1, 0)
#define S5P_GPK1_0_IN			(0x0)
#define S5P_GPK1_0_OUT			(0x1)
#define S5P_GPK1_0_EBI_BEn0		(0x2)

#define S5P_GPK1_1			S5P_GPIO_NO(S5P_GPIO_BANK_K1, 1)
#define S5P_GPK1_1_IN			(0x0)
#define S5P_GPK1_1_OUT			(0x1)
#define S5P_GPK1_1_EBI_BEn1		(0x2)

#define S5P_GPK1_2			S5P_GPIO_NO(S5P_GPIO_BANK_K1, 2)
#define S5P_GPK1_2_IN			(0x0)
#define S5P_GPK1_2_OUT			(0x1)
#define S5P_GPK1_2_SROM_WAITn		(0x2)

#define S5P_GPK1_3			S5P_GPIO_NO(S5P_GPIO_BANK_K1, 3)
#define S5P_GPK1_3_IN			(0x0)
#define S5P_GPK1_3_OUT			(0x1)
#define S5P_GPK1_3_EBI_DATA_RDn		(0x2)

#define S5P_GPK1_4			S5P_GPIO_NO(S5P_GPIO_BANK_K1, 4)
#define S5P_GPK1_4_IN			(0x0)
#define S5P_GPK1_4_OUT			(0x1)
#define S5P_GPK1_4_CF_OEn		(0x2)

#define S5P_GPK1_5			S5P_GPIO_NO(S5P_GPIO_BANK_K1, 5)
#define S5P_GPK1_5_IN			(0x0)
#define S5P_GPK1_5_OUT			(0x1)
#define S5P_GPK1_5_CF_WEn		(0x2)

/* GPK2 */
#define S5P_GPK2_CON			S5P_GPIO_REG(0x2E0)
#define S5P_GPK2_DAT			S5P_GPIO_REG(0x2E4)
#define S5P_GPK2_PUD			S5P_GPIO_REG(0x2E8)
#define S5P_GPK2_DRV			S5P_GPIO_REG(0x2EC)
#define S5P_GPK2_CONPDN			S5P_GPIO_REG(0x2F0)
#define S5P_GPK2_PUDPDN			S5P_GPIO_REG(0x2F4)

#define S5P_GPK2_0			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 0)
#define S5P_GPK2_0_IN			(0x0)
#define S5P_GPK2_0_OUT			(0x1)
#define S5P_GPK2_0_NF_CLE		(0x3)
#define S5P_GPK2_0_ONENAND_ADDRVALID	(0x5)

#define S5P_GPK2_1			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 1)
#define S5P_GPK2_1_IN			(0x0)
#define S5P_GPK2_1_OUT			(0x1)
#define S5P_GPK2_1_NF_ALE		(0x3)
#define S5P_GPK2_1_ONENAND_SMCLK	(0x5)

#define S5P_GPK2_2			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 2)
#define S5P_GPK2_2_IN			(0x0)
#define S5P_GPK2_2_OUT			(0x1)
#define S5P_GPK2_2_NF_FWEn		(0x3)
#define S5P_GPK2_2_ONENAND_RPn		(0x5)

#define S5P_GPK2_3			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 3)
#define S5P_GPK2_3_IN			(0x0)
#define S5P_GPK2_3_OUT			(0x1)
#define S5P_GPK2_3_NF_FREn		(0x3)

#define S5P_GPK2_4			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 4)
#define S5P_GPK2_4_IN			(0x0)
#define S5P_GPK2_4_OUT			(0x1)
#define S5P_GPK2_4_NF_RnB0		(0x2)
#define S5P_GPK2_4_ONENAND_INT0		(0x5)

#define S5P_GPK2_5			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 5)
#define S5P_GPK2_5_IN			(0x0)
#define S5P_GPK2_5_OUT			(0x1)
#define S5P_GPK2_5_NF_RnB1		(0x2)
#define S5P_GPK2_5_ONENAND_INT1		(0x5)

#define S5P_GPK2_6			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 6)
#define S5P_GPK2_6_IN			(0x0)
#define S5P_GPK2_6_OUT			(0x1)
#define S5P_GPK2_6_NF_RnB2		(0x2)

#define S5P_GPK2_7			S5P_GPIO_NO(S5P_GPIO_BANK_K2, 7)
#define S5P_GPK2_7_IN			(0x0)
#define S5P_GPK2_7_OUT			(0x1)
#define S5P_GPK2_7_NF_RnB3		(0x2)

/* GPK3 */
#define S5P_GPK3_CON			S5P_GPIO_REG(0x300)
#define S5P_GPK3_DAT			S5P_GPIO_REG(0x304)
#define S5P_GPK3_PUD			S5P_GPIO_REG(0x308)
#define S5P_GPK3_DRV			S5P_GPIO_REG(0x30C)
#define S5P_GPK3_CONPDN			S5P_GPIO_REG(0x310)
#define S5P_GPK3_PUDPDN			S5P_GPIO_REG(0x314)

#define S5P_GPK3_0			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 0)
#define S5P_GPK3_0_IN			(0x0)
#define S5P_GPK3_0_OUT			(0x1)
#define S5P_GPK3_0_CF_IORDY		(0x2)

#define S5P_GPK3_1			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 1)
#define S5P_GPK3_1_IN			(0x0)
#define S5P_GPK3_1_OUT			(0x1)
#define S5P_GPK3_1_CF_INTRQ		(0x2)

#define S5P_GPK3_2			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 2)
#define S5P_GPK3_2_IN			(0x0)
#define S5P_GPK3_2_OUT			(0x1)
#define S5P_GPK3_2_CF_RESET		(0x2)

#define S5P_GPK3_3			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 3)
#define S5P_GPK3_3_IN			(0x0)
#define S5P_GPK3_3_OUT			(0x1)
#define S5P_GPK3_3_CF_INPACKn		(0x2)

#define S5P_GPK3_4			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 4)
#define S5P_GPK3_4_IN			(0x0)
#define S5P_GPK3_4_OUT			(0x1)
#define S5P_GPK3_4_CF_REG		(0x2)

#define S5P_GPK3_5			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 5)
#define S5P_GPK3_5_IN			(0x0)
#define S5P_GPK3_5_OUT			(0x1)
#define S5P_GPK3_5_CF_CDn		(0x2)

#define S5P_GPK3_6			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 6)
#define S5P_GPK3_6_IN			(0x0)
#define S5P_GPK3_6_OUT			(0x1)
#define S5P_GPK3_6_CF_IORD_CFn		(0x2)

#define S5P_GPK3_7			S5P_GPIO_NO(S5P_GPIO_BANK_K3, 7)
#define S5P_GPK3_7_IN			(0x0)
#define S5P_GPK3_7_OUT			(0x1)
#define S5P_GPK3_7_CF_IOWR_CFn		(0x2)

/* MP0_0 */
#define S5P_MP0_0CON			S5P_GPIO_REG(0x320)
#define S5P_MP0_0DAT			S5P_GPIO_REG(0x324)
#define S5P_MP0_0PUD			S5P_GPIO_REG(0x328)
#define S5P_MP0_0DRV			S5P_GPIO_REG(0x32C)
#define S5P_MP0_0CONPDN			S5P_GPIO_REG(0x330)
#define S5P_MP0_0PUDPDN			S5P_GPIO_REG(0x334)

#define S5P_MP0_00			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 0)
#define S5P_MP0_00_IN			(0x0)
#define S5P_MP0_00_OUT			(0x1)
#define S5P_MP0_00_EBI_ADDR0		(0x2)

#define S5P_MP0_01			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 1)
#define S5P_MP0_01_IN			(0x0)
#define S5P_MP0_01_OUT			(0x1)
#define S5P_MP0_01_EBI_ADDR1		(0x2)

#define S5P_MP0_02			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 2)
#define S5P_MP0_02_IN			(0x0)
#define S5P_MP0_02_OUT			(0x1)
#define S5P_MP0_02_EBI_ADDR2		(0x2)

#define S5P_MP0_03			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 3)
#define S5P_MP0_03_IN			(0x0)
#define S5P_MP0_03_OUT			(0x1)
#define S5P_MP0_03_EBI_ADDR3		(0x2)

#define S5P_MP0_04			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 4)
#define S5P_MP0_04_IN			(0x0)
#define S5P_MP0_04_OUT			(0x1)
#define S5P_MP0_04_EBI_ADDR4		(0x2)

#define S5P_MP0_05			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 5)
#define S5P_MP0_05_IN			(0x0)
#define S5P_MP0_05_OUT			(0x1)
#define S5P_MP0_05_EBI_ADDR5		(0x2)

#define S5P_MP0_06			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 6)
#define S5P_MP0_06_IN			(0x0)
#define S5P_MP0_06_OUT			(0x1)
#define S5P_MP0_06_EBI_ADDR6		(0x2)

#define S5P_MP0_07			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_0, 7)
#define S5P_MP0_07_IN			(0x0)
#define S5P_MP0_07_OUT			(0x1)
#define S5P_MP0_07_EBI_ADDR7		(0x2)

/* MP0_1 */
#define S5P_MP0_1CON			S5P_GPIO_REG(0x340)
#define S5P_MP0_1DAT			S5P_GPIO_REG(0x344)
#define S5P_MP0_1PUD			S5P_GPIO_REG(0x348)
#define S5P_MP0_1DRV			S5P_GPIO_REG(0x34C)
#define S5P_MP0_1CONPDN			S5P_GPIO_REG(0x350)
#define S5P_MP0_1PUDPDN			S5P_GPIO_REG(0x354)

#define S5P_MP0_10			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 0)
#define S5P_MP0_10_IN			(0x0)
#define S5P_MP0_10_OUT			(0x1)
#define S5P_MP0_10_EBI_ADDR8		(0x2)

#define S5P_MP0_11			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 1)
#define S5P_MP0_11_IN			(0x0)
#define S5P_MP0_11_OUT			(0x1)
#define S5P_MP0_11_EBI_ADDR9		(0x2)

#define S5P_MP0_12			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 2)
#define S5P_MP0_12_IN			(0x0)
#define S5P_MP0_12_OUT			(0x1)
#define S5P_MP0_12_EBI_ADDR10		(0x2)

#define S5P_MP0_13			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 3)
#define S5P_MP0_13_IN			(0x0)
#define S5P_MP0_13_OUT			(0x1)
#define S5P_MP0_13_EBI_ADDR11		(0x2)

#define S5P_MP0_14			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 4)
#define S5P_MP0_14_IN			(0x0)
#define S5P_MP0_14_OUT			(0x1)
#define S5P_MP0_14_EBI_ADDR12		(0x2)

#define S5P_MP0_15			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 5)
#define S5P_MP0_15_IN			(0x0)
#define S5P_MP0_15_OUT			(0x1)
#define S5P_MP0_15_EBI_ADDR13		(0x2)

#define S5P_MP0_16			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 6)
#define S5P_MP0_16_IN			(0x0)
#define S5P_MP0_16_OUT			(0x1)
#define S5P_MP0_16_EBI_ADDR14		(0x2)

#define S5P_MP0_17			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_1, 7)
#define S5P_MP0_17_IN			(0x0)
#define S5P_MP0_17_OUT			(0x1)
#define S5P_MP0_17_EBI_ADDR15		(0x2)

/* MP0_2 */
#define S5P_MP0_2CON			S5P_GPIO_REG(0x360)
#define S5P_MP0_2DAT			S5P_GPIO_REG(0x364)
#define S5P_MP0_2PUD			S5P_GPIO_REG(0x368)
#define S5P_MP0_2DRV			S5P_GPIO_REG(0x36C)
#define S5P_MP0_2CONPDN			S5P_GPIO_REG(0x370)
#define S5P_MP0_2PUDPDN			S5P_GPIO_REG(0x374)

#define S5P_MP0_20			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 0)
#define S5P_MP0_20_IN			(0x0)
#define S5P_MP0_20_OUT			(0x1)
#define S5P_MP0_20_EBI_ADDR16		(0x2)

#define S5P_MP0_21			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 1)
#define S5P_MP0_21_IN			(0x0)
#define S5P_MP0_21_OUT			(0x1)
#define S5P_MP0_21_EBI_ADDR17		(0x2)

#define S5P_MP0_22			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 2)
#define S5P_MP0_22_IN			(0x0)
#define S5P_MP0_22_OUT			(0x1)
#define S5P_MP0_22_EBI_ADDR18		(0x2)

#define S5P_MP0_23			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 3)
#define S5P_MP0_23_IN			(0x0)
#define S5P_MP0_23_OUT			(0x1)
#define S5P_MP0_23_EBI_ADDR19		(0x2)

#define S5P_MP0_24			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 4)
#define S5P_MP0_24_IN			(0x0)
#define S5P_MP0_24_OUT			(0x1)
#define S5P_MP0_24_EBI_ADDR20		(0x2)

#define S5P_MP0_25			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 5)
#define S5P_MP0_25_IN			(0x0)
#define S5P_MP0_25_OUT			(0x1)
#define S5P_MP0_25_EBI_DATA0		(0x2)

#define S5P_MP0_26			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 6)
#define S5P_MP0_26_IN			(0x0)
#define S5P_MP0_26_OUT			(0x1)
#define S5P_MP0_26_EBI_DATA1		(0x2)

#define S5P_MP0_27			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_2, 7)
#define S5P_MP0_27_IN			(0x0)
#define S5P_MP0_27_OUT			(0x1)
#define S5P_MP0_27_EBI_DATA2		(0x2)

/* MP0_3 */
#define S5P_MP0_3CON			S5P_GPIO_REG(0x380)
#define S5P_MP0_3DAT			S5P_GPIO_REG(0x384)
#define S5P_MP0_3PUD			S5P_GPIO_REG(0x388)
#define S5P_MP0_3DRV			S5P_GPIO_REG(0x38C)
#define S5P_MP0_3CONPDN			S5P_GPIO_REG(0x390)
#define S5P_MP0_3PUDPDN			S5P_GPIO_REG(0x394)

#define S5P_MP0_30			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 0)
#define S5P_MP0_30_IN			(0x0)
#define S5P_MP0_30_OUT			(0x1)
#define S5P_MP0_30_EBI_DATA3		(0x2)

#define S5P_MP0_31			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 1)
#define S5P_MP0_31_IN			(0x0)
#define S5P_MP0_31_OUT			(0x1)
#define S5P_MP0_31_EBI_DATA4		(0x2)

#define S5P_MP0_32			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 2)
#define S5P_MP0_32_IN			(0x0)
#define S5P_MP0_32_OUT			(0x1)
#define S5P_MP0_32_EBI_DATA5		(0x2)

#define S5P_MP0_33			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 3)
#define S5P_MP0_33_IN			(0x0)
#define S5P_MP0_33_OUT			(0x1)
#define S5P_MP0_33_EBI_DATA6		(0x2)

#define S5P_MP0_34			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 4)
#define S5P_MP0_34_IN			(0x0)
#define S5P_MP0_34_OUT			(0x1)
#define S5P_MP0_34_EBI_DATA7		(0x2)

#define S5P_MP0_35			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 5)
#define S5P_MP0_35_IN			(0x0)
#define S5P_MP0_35_OUT			(0x1)
#define S5P_MP0_35_EBI_DATA8		(0x2)

#define S5P_MP0_36			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 6)
#define S5P_MP0_36_IN			(0x0)
#define S5P_MP0_36_OUT			(0x1)
#define S5P_MP0_36_EBI_DATA9		(0x2)

#define S5P_MP0_37			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_3, 7)
#define S5P_MP0_37_IN			(0x0)
#define S5P_MP0_37_OUT			(0x1)
#define S5P_MP0_37_EBI_DATA10		(0x2)

/* MP0_4 */
#define S5P_MP0_4CON			S5P_GPIO_REG(0x3A0)
#define S5P_MP0_4DAT			S5P_GPIO_REG(0x3A4)
#define S5P_MP0_4PUD			S5P_GPIO_REG(0x3A8)
#define S5P_MP0_4DRV			S5P_GPIO_REG(0x3AC)
#define S5P_MP0_4CONPDN			S5P_GPIO_REG(0x3B0)
#define S5P_MP0_4PUDPDN			S5P_GPIO_REG(0x3B4)

#define S5P_MP0_40			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_4, 0)
#define S5P_MP0_40_IN			(0x0)
#define S5P_MP0_40_OUT			(0x1)
#define S5P_MP0_40_EBI_DATA11		(0x2)

#define S5P_MP0_41			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_4, 1)
#define S5P_MP0_41_IN			(0x0)
#define S5P_MP0_41_OUT			(0x1)
#define S5P_MP0_41_EBI_DATA12		(0x2)

#define S5P_MP0_42			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_4, 2)
#define S5P_MP0_42_IN			(0x0)
#define S5P_MP0_42_OUT			(0x1)
#define S5P_MP0_42_EBI_DATA13		(0x2)

#define S5P_MP0_43			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_4, 3)
#define S5P_MP0_43_IN			(0x0)
#define S5P_MP0_43_OUT			(0x1)
#define S5P_MP0_43_EBI_DATA14		(0x2)

#define S5P_MP0_44			S5P_GPIO_NO(S5P_GPIO_BANK_MP0_4, 4)
#define S5P_MP0_44_IN			(0x0)
#define S5P_MP0_44_OUT			(0x1)
#define S5P_MP0_44_EBI_DATA15		(0x2)

/* MP1_0 */
#define S5P_MP1_0PUD			S5P_GPIO_REG(0x3C8)
#define S5P_MP1_0DRV			S5P_GPIO_REG(0x3CC)
#define S5P_MP1_0CONPDN			S5P_GPIO_REG(0x3D0)
#define S5P_MP1_0PUDPDN			S5P_GPIO_REG(0x3D4)

/* MP1_1 */
#define S5P_MP1_1PUD			S5P_GPIO_REG(0x3E8)
#define S5P_MP1_1DRV			S5P_GPIO_REG(0x3EC)
#define S5P_MP1_1CONPDN			S5P_GPIO_REG(0x3F0)
#define S5P_MP1_1PUDPDN			S5P_GPIO_REG(0x3F4)

/* MP1_2 */
#define S5P_MP1_2PUD			S5P_GPIO_REG(0x408)
#define S5P_MP1_2DRV			S5P_GPIO_REG(0x40C)
#define S5P_MP1_2CONPDN			S5P_GPIO_REG(0x410)
#define S5P_MP1_2PUDPDN			S5P_GPIO_REG(0x414)

/* MP1_3 */
#define S5P_MP1_3PUD			S5P_GPIO_REG(0x428)
#define S5P_MP1_3DRV			S5P_GPIO_REG(0x42C)
#define S5P_MP1_3CONPDN			S5P_GPIO_REG(0x430)
#define S5P_MP1_3PUDPDN			S5P_GPIO_REG(0x434)

/* MP1_4 */
#define S5P_MP1_4PUD			S5P_GPIO_REG(0x448)
#define S5P_MP1_4DRV			S5P_GPIO_REG(0x44C)
#define S5P_MP1_4CONPDN			S5P_GPIO_REG(0x450)
#define S5P_MP1_4PUDPDN			S5P_GPIO_REG(0x454)

/* MP1_5 */
#define S5P_MP1_5PUD			S5P_GPIO_REG(0x468)
#define S5P_MP1_5DRV			S5P_GPIO_REG(0x46C)
#define S5P_MP1_5CONPDN			S5P_GPIO_REG(0x470)
#define S5P_MP1_5PUDPDN			S5P_GPIO_REG(0x474)

/* MP1_6 */
#define S5P_MP1_6PUD			S5P_GPIO_REG(0x488)
#define S5P_MP1_6DRV			S5P_GPIO_REG(0x48C)
#define S5P_MP1_6CONPDN			S5P_GPIO_REG(0x490)
#define S5P_MP1_6PUDPDN			S5P_GPIO_REG(0x494)

/* MP1_7*/
#define S5P_MP1_7PUD			S5P_GPIO_REG(0x4A8)
#define S5P_MP1_7DRV			S5P_GPIO_REG(0x4AC)
#define S5P_MP1_7CONPDN			S5P_GPIO_REG(0x4B0)
#define S5P_MP1_7PUDPDN			S5P_GPIO_REG(0x4B4)

/* MP1_8*/
#define S5P_MP1_8PUD			S5P_GPIO_REG(0x4C8)
#define S5P_MP1_8DRV			S5P_GPIO_REG(0x4CC)
#define S5P_MP1_8CONPDN			S5P_GPIO_REG(0x4D0)
#define S5P_MP1_8PUDPDN			S5P_GPIO_REG(0x4D4)

/* ETC0 */
#define S5P_ETC0_PUD			S5P_GPIO_REG(0x4E8)
#define S5P_ETC0_DRV			S5P_GPIO_REG(0x4EC)

/* ETC1 */
#define S5P_ETC1_PUD			S5P_GPIO_REG(0x508)
#define S5P_ETC1_DRV			S5P_GPIO_REG(0x50C)

/* ETC2 */
#define S5P_ETC2_PUD			S5P_GPIO_REG(0x528)
#define S5P_ETC2_DRV			S5P_GPIO_REG(0x52C)

/* ETC3 */
#define S5P_ETC3_PUD			S5P_GPIO_REG(0x548)
#define S5P_ETC3_DRV			S5P_GPIO_REG(0x54C)

/* ETC4 */
#define S5P_ETC4_PUD			S5P_GPIO_REG(0x568)
#define S5P_ETC4_DRV			S5P_GPIO_REG(0x56C)

/* External Interrupt Control Registers */
#define S5P_EXT_INT1_CON		S5P_GPIO_REG(0x700)
#define S5P_EXT_INT2_CON		S5P_GPIO_REG(0x704)
#define S5P_EXT_INT3_CON		S5P_GPIO_REG(0x708)
#define S5P_EXT_INT4_CON		S5P_GPIO_REG(0x70C)
#define S5P_EXT_INT5_CON		S5P_GPIO_REG(0x710)
#define S5P_EXT_INT6_CON		S5P_GPIO_REG(0x714)
#define S5P_EXT_INT7_CON		S5P_GPIO_REG(0x718)
#define S5P_EXT_INT8_CON		S5P_GPIO_REG(0x71C)
#define S5P_EXT_INT9_CON		S5P_GPIO_REG(0x720)
#define S5P_EXT_INT10_CON		S5P_GPIO_REG(0x724)
#define S5P_EXT_INT11_CON		S5P_GPIO_REG(0x728)
#define S5P_EXT_INT12_CON		S5P_GPIO_REG(0x72C)
#define S5P_EXT_INT13_CON		S5P_GPIO_REG(0x730)
#define S5P_EXT_INT14_CON		S5P_GPIO_REG(0x734)
#define S5P_EXT_INT15_CON		S5P_GPIO_REG(0x738)
#define S5P_EXT_INT20_CON		S5P_GPIO_REG(0x73C)
#define S5P_EXT_INT21_CON		S5P_GPIO_REG(0x740)
#define S5P_EXT_INT22_CON		S5P_GPIO_REG(0x744)
#define S5P_EXT_INT23_CON		S5P_GPIO_REG(0x748)
#define S5P_EXT_INT24_CON		S5P_GPIO_REG(0x74C)
#define S5P_EXT_INT25_CON		S5P_GPIO_REG(0x750)
#define S5P_EXT_INT1_FLTCON0		S5P_GPIO_REG(0x800)
#define S5P_EXT_INT1_FLTCON1		S5P_GPIO_REG(0x804)
#define S5P_EXT_INT2_FLTCON0		S5P_GPIO_REG(0x808)
#define S5P_EXT_INT2_FLTCON1		S5P_GPIO_REG(0x80C)
#define S5P_EXT_INT3_FLTCON0		S5P_GPIO_REG(0x810)
#define S5P_EXT_INT3_FLTCON1		S5P_GPIO_REG(0x814)
#define S5P_EXT_INT4_FLTCON0		S5P_GPIO_REG(0x818)
#define S5P_EXT_INT4_FLTCON1		S5P_GPIO_REG(0x81C)
#define S5P_EXT_INT5_FLTCON0		S5P_GPIO_REG(0x820)
#define S5P_EXT_INT5_FLTCON1		S5P_GPIO_REG(0x824)
#define S5P_EXT_INT6_FLTCON0		S5P_GPIO_REG(0x828)
#define S5P_EXT_INT6_FLTCON1		S5P_GPIO_REG(0x82C)
#define S5P_EXT_INT7_FLTCON0		S5P_GPIO_REG(0x830)
#define S5P_EXT_INT7_FLTCON1		S5P_GPIO_REG(0x834)
#define S5P_EXT_INT8_FLTCON0		S5P_GPIO_REG(0x838)
#define S5P_EXT_INT8_FLTCON1		S5P_GPIO_REG(0x83C)
#define S5P_EXT_INT9_FLTCON0		S5P_GPIO_REG(0x840)
#define S5P_EXT_INT9_FLTCON1		S5P_GPIO_REG(0x844)
#define S5P_EXT_INT10_FLTCON0		S5P_GPIO_REG(0x848)
#define S5P_EXT_INT10_FLTCON1		S5P_GPIO_REG(0x84C)
#define S5P_EXT_INT11_FLTCON0		S5P_GPIO_REG(0x850)
#define S5P_EXT_INT11_FLTCON1		S5P_GPIO_REG(0x854)
#define S5P_EXT_INT12_FLTCON0		S5P_GPIO_REG(0x858)
#define S5P_EXT_INT12_FLTCON1		S5P_GPIO_REG(0x85C)
#define S5P_EXT_INT13_FLTCON0		S5P_GPIO_REG(0x860)
#define S5P_EXT_INT13_FLTCON1		S5P_GPIO_REG(0x864)
#define S5P_EXT_INT14_FLTCON0		S5P_GPIO_REG(0x868)
#define S5P_EXT_INT14_FLTCON1		S5P_GPIO_REG(0x86C)
#define S5P_EXT_INT15_FLTCON0		S5P_GPIO_REG(0x870)
#define S5P_EXT_INT15_FLTCON1		S5P_GPIO_REG(0x874)
#define S5P_EXT_INT20_FLTCON0		S5P_GPIO_REG(0x878)
#define S5P_EXT_INT20_FLTCON1		S5P_GPIO_REG(0x87C)
#define S5P_EXT_INT21_FLTCON0		S5P_GPIO_REG(0x880)
#define S5P_EXT_INT21_FLTCON1		S5P_GPIO_REG(0x884)
#define S5P_EXT_INT22_FLTCON0		S5P_GPIO_REG(0x888)
#define S5P_EXT_INT22_FLTCON1		S5P_GPIO_REG(0x88C)
#define S5P_EXT_INT23_FLTCON0		S5P_GPIO_REG(0x890)
#define S5P_EXT_INT23_FLTCON1		S5P_GPIO_REG(0x894)
#define S5P_EXT_INT24_FLTCON0		S5P_GPIO_REG(0x898)
#define S5P_EXT_INT24_FLTCON1		S5P_GPIO_REG(0x89C)
#define S5P_EXT_INT25_FLTCON0		S5P_GPIO_REG(0x8A0)
#define S5P_EXT_INT25_FLTCON1		S5P_GPIO_REG(0x8A4)
#define S5P_EXT_INT1_MASK		S5P_GPIO_REG(0x900)
#define S5P_EXT_INT2_MASK		S5P_GPIO_REG(0x904)
#define S5P_EXT_INT3_MASK		S5P_GPIO_REG(0x908)
#define S5P_EXT_INT4_MASK		S5P_GPIO_REG(0x90C)
#define S5P_EXT_INT5_MASK		S5P_GPIO_REG(0x910)
#define S5P_EXT_INT6_MASK		S5P_GPIO_REG(0x914)
#define S5P_EXT_INT7_MASK		S5P_GPIO_REG(0x918)
#define S5P_EXT_INT8_MASK		S5P_GPIO_REG(0x91C)
#define S5P_EXT_INT9_MASK		S5P_GPIO_REG(0x920)
#define S5P_EXT_INT10_MASK		S5P_GPIO_REG(0x924)
#define S5P_EXT_INT11_MASK		S5P_GPIO_REG(0x928)
#define S5P_EXT_INT12_MASK		S5P_GPIO_REG(0x92C)
#define S5P_EXT_INT13_MASK		S5P_GPIO_REG(0x930)
#define S5P_EXT_INT14_MASK		S5P_GPIO_REG(0x934)
#define S5P_EXT_INT15_MASK		S5P_GPIO_REG(0x938)
#define S5P_EXT_INT20_MASK		S5P_GPIO_REG(0x93C)
#define S5P_EXT_INT21_MASK		S5P_GPIO_REG(0x940)
#define S5P_EXT_INT22_MASK		S5P_GPIO_REG(0x944)
#define S5P_EXT_INT23_MASK		S5P_GPIO_REG(0x948)
#define S5P_EXT_INT24_MASK		S5P_GPIO_REG(0x94C)
#define S5P_EXT_INT25_MASK		S5P_GPIO_REG(0x950)
#define S5P_EXT_INT1_PEND		S5P_GPIO_REG(0xA00)
#define S5P_EXT_INT2_PEND		S5P_GPIO_REG(0xA04)
#define S5P_EXT_INT3_PEND		S5P_GPIO_REG(0xA08)
#define S5P_EXT_INT4_PEND		S5P_GPIO_REG(0xA0C)
#define S5P_EXT_INT5_PEND		S5P_GPIO_REG(0xA10)
#define S5P_EXT_INT6_PEND		S5P_GPIO_REG(0xA14)
#define S5P_EXT_INT7_PEND		S5P_GPIO_REG(0xA18)
#define S5P_EXT_INT8_PEND		S5P_GPIO_REG(0xA1C)
#define S5P_EXT_INT9_PEND		S5P_GPIO_REG(0xA20)
#define S5P_EXT_INT10_PEND		S5P_GPIO_REG(0xA24)
#define S5P_EXT_INT11_PEND		S5P_GPIO_REG(0xA28)
#define S5P_EXT_INT12_PEND		S5P_GPIO_REG(0xA2C)
#define S5P_EXT_INT13_PEND		S5P_GPIO_REG(0xA30)
#define S5P_EXT_INT14_PEND		S5P_GPIO_REG(0xA34)
#define S5P_EXT_INT15_PEND		S5P_GPIO_REG(0xA38)
#define S5P_EXT_INT20_PEND		S5P_GPIO_REG(0xA3C)
#define S5P_EXT_INT21_PEND		S5P_GPIO_REG(0xA40)
#define S5P_EXT_INT22_PEND		S5P_GPIO_REG(0xA44)
#define S5P_EXT_INT23_PEND		S5P_GPIO_REG(0xA48)
#define S5P_EXT_INT24_PEND		S5P_GPIO_REG(0xA4C)
#define S5P_EXT_INT25_PEND		S5P_GPIO_REG(0xA50)
#define S5P_EXT_INT_GRPPRI		S5P_GPIO_REG(0xB00)
#define S5P_EXT_INT_PRIORITY		S5P_GPIO_REG(0xB04)
#define S5P_EXT_INT_SERVICE		S5P_GPIO_REG(0xB08)
#define S5P_EXT_INT_SERVICE_PEND	S5P_GPIO_REG(0xB0C)
#define S5P_EXT_INT_GRPFIXPRI		S5P_GPIO_REG(0xB10)
#define S5P_EXT_INT1_FIXPRI		S5P_GPIO_REG(0xB14)
#define S5P_EXT_INT2_FIXPRI		S5P_GPIO_REG(0xB18)
#define S5P_EXT_INT3_FIXPRI		S5P_GPIO_REG(0xB1C)
#define S5P_EXT_INT4_FIXPRI		S5P_GPIO_REG(0xB20)
#define S5P_EXT_INT5_FIXPRI		S5P_GPIO_REG(0xB24)
#define S5P_EXT_INT6_FIXPRI		S5P_GPIO_REG(0xB28)
#define S5P_EXT_INT7_FIXPRI		S5P_GPIO_REG(0xB2C)
#define S5P_EXT_INT8_FIXPRI		S5P_GPIO_REG(0xB30)
#define S5P_EXT_INT9_FIXPRI		S5P_GPIO_REG(0xB34)
#define S5P_EXT_INT10_FIXPRI		S5P_GPIO_REG(0xB38)
#define S5P_EXT_INT11_FIXPRI		S5P_GPIO_REG(0xB3C)
#define S5P_EXT_INT12_FIXPRI		S5P_GPIO_REG(0xB40)
#define S5P_EXT_INT13_FIXPRI		S5P_GPIO_REG(0xB44)
#define S5P_EXT_INT14_FIXPRI		S5P_GPIO_REG(0xB48)
#define S5P_EXT_INT15_FIXPRI		S5P_GPIO_REG(0xB4C)
#define S5P_EXT_INT20_FIXPRI		S5P_GPIO_REG(0xB50)
#define S5P_EXT_INT21_FIXPRI		S5P_GPIO_REG(0xB54)
#define S5P_EXT_INT22_FIXPRI		S5P_GPIO_REG(0xB58)
#define S5P_EXT_INT23_FIXPRI		S5P_GPIO_REG(0xB5C)
#define S5P_EXT_INT24_FIXPRI		S5P_GPIO_REG(0xB60)
#define S5P_EXT_INT25_FIXPRI		S5P_GPIO_REG(0xB64)
#define S5P_UHOST			S5P_GPIO_REG(0xB68)
#define	S5P_PDNEN			S5P_GPIO_REG(0xF80)

#endif

